diff --git a/.gitignore b/.gitignore
index cd86e34..f539444 100644
--- a/.gitignore
+++ b/.gitignore
@@ -14,6 +14,7 @@
 /feeds.conf
 /files
 /package/feeds
+/package/lede-packages
 /package/openwrt-packages
 key-build*
 *.orig
diff --git a/include/toplevel.mk b/include/toplevel.mk
index 9709302..eecc61b 100644
--- a/include/toplevel.mk
+++ b/include/toplevel.mk
@@ -92,7 +92,7 @@ prepare-tmpinfo: FORCE
 
 .config: ./scripts/config/conf $(if $(CONFIG_HAVE_DOT_CONFIG),,prepare-tmpinfo)
 	@+if [ \! -e .config ] || ! grep CONFIG_HAVE_DOT_CONFIG .config >/dev/null; then \
-		[ -e $(HOME)/.openwrt/defconfig ] && cp $(HOME)/.openwrt/defconfig .config; \
+		[ -e $(HOME)/.lede/defconfig ] && cp $(HOME)/.lede/defconfig .config; \
 		$(_SINGLE)$(NO_TRACE_MAKE) menuconfig $(PREP_MK); \
 	fi
 
@@ -112,7 +112,7 @@ config-clean: FORCE
 
 defconfig: scripts/config/conf prepare-tmpinfo FORCE
 	touch .config
-	@if [ -e $(HOME)/.openwrt/defconfig ]; then cp $(HOME)/.openwrt/defconfig .config; fi
+	@if [ -e $(HOME)/.lede/defconfig ]; then cp $(HOME)/.lede/defconfig .config; fi
 	$< --defconfig=.config Config.in
 
 confdefault-y=allyes
@@ -124,8 +124,8 @@ oldconfig: scripts/config/conf prepare-tmpinfo FORCE
 	$< --$(if $(confdefault),$(confdefault),old)config Config.in
 
 menuconfig: scripts/config/mconf prepare-tmpinfo FORCE
-	if [ \! -e .config -a -e $(HOME)/.openwrt/defconfig ]; then \
-		cp $(HOME)/.openwrt/defconfig .config; \
+	if [ \! -e .config -a -e $(HOME)/.lede/defconfig ]; then \
+		cp $(HOME)/.lede/defconfig .config; \
 	fi
 	$< Config.in
 
@@ -228,7 +228,7 @@ docs/clean: FORCE
 	@$(_SINGLE)$(SUBMAKE) -C docs clean
 
 distclean:
-	rm -rf bin build_dir .config* dl feeds key-build* logs package/feeds package/openwrt-packages staging_dir tmp
+	rm -rf bin build_dir .config* dl feeds key-build* logs package/feeds package/lede-packages staging_dir tmp
 	@$(_SINGLE)$(SUBMAKE) -C scripts/config clean
 
 ifeq ($(findstring v,$(DEBUG)),)
diff --git a/package/base-files/files/etc/lede_release b/package/base-files/files/etc/lede_release
new file mode 100644
index 0000000..9b2a40c
--- /dev/null
+++ b/package/base-files/files/etc/lede_release
@@ -0,0 +1,7 @@
+DISTRIB_ID='%D'
+DISTRIB_RELEASE='%C'
+DISTRIB_REVISION='%R'
+DISTRIB_CODENAME='%n'
+DISTRIB_TARGET='%S'
+DISTRIB_DESCRIPTION='%D %N %V'
+DISTRIB_TAINTS='%t'
diff --git a/package/base-files/files/etc/lede_version b/package/base-files/files/etc/lede_version
new file mode 100644
index 0000000..4b14f59
--- /dev/null
+++ b/package/base-files/files/etc/lede_version
@@ -0,0 +1 @@
+%V
diff --git a/package/base-files/files/etc/openwrt_release b/package/base-files/files/etc/openwrt_release
deleted file mode 100644
index 9b2a40c..0000000
--- a/package/base-files/files/etc/openwrt_release
+++ /dev/null
@@ -1,7 +0,0 @@
-DISTRIB_ID='%D'
-DISTRIB_RELEASE='%C'
-DISTRIB_REVISION='%R'
-DISTRIB_CODENAME='%n'
-DISTRIB_TARGET='%S'
-DISTRIB_DESCRIPTION='%D %N %V'
-DISTRIB_TAINTS='%t'
diff --git a/package/base-files/files/etc/openwrt_version b/package/base-files/files/etc/openwrt_version
deleted file mode 100644
index 4b14f59..0000000
--- a/package/base-files/files/etc/openwrt_version
+++ /dev/null
@@ -1 +0,0 @@
-%V
diff --git a/package/boot/apex/patches/100-openwrt_nslu2_armeb_config.patch b/package/boot/apex/patches/100-openwrt_nslu2_armeb_config.patch
index d598ff3..a768d0a 100644
--- a/package/boot/apex/patches/100-openwrt_nslu2_armeb_config.patch
+++ b/package/boot/apex/patches/100-openwrt_nslu2_armeb_config.patch
@@ -5,7 +5,7 @@
  # General Setup
  #
 -CONFIG_TARGET_DESCRIPTION="SlugOS NSLU2 (bigendian)"
-+CONFIG_TARGET_DESCRIPTION="OpenWrt NSLU2 (8MiB Flash)"
++CONFIG_TARGET_DESCRIPTION="LEDE NSLU2 (8MiB Flash)"
  CONFIG_CROSS_COMPILE=""
  CONFIG_AEABI=y
  # CONFIG_DRIVER_LONG_LONG_SIZE is not set
diff --git a/package/boot/apex/patches/120-openwrt_nslu2_16mb_armeb_config.patch b/package/boot/apex/patches/120-openwrt_nslu2_16mb_armeb_config.patch
index 5e7ecee..3e26e43 100644
--- a/package/boot/apex/patches/120-openwrt_nslu2_16mb_armeb_config.patch
+++ b/package/boot/apex/patches/120-openwrt_nslu2_16mb_armeb_config.patch
@@ -5,7 +5,7 @@
  # General Setup
  #
 -CONFIG_TARGET_DESCRIPTION="SlugOS NSLU2/BE (16MiB Flash)"
-+CONFIG_TARGET_DESCRIPTION="OpenWrt NSLU2 (16MiB Flash)"
++CONFIG_TARGET_DESCRIPTION="LEDE NSLU2 (16MiB Flash)"
  CONFIG_CROSS_COMPILE=""
  CONFIG_AEABI=y
  # CONFIG_DRIVER_LONG_LONG_SIZE is not set
diff --git a/package/boot/apex/patches/140-openwrt_fsg3_armeb_config.patch b/package/boot/apex/patches/140-openwrt_fsg3_armeb_config.patch
index fc0e8b9..7097734 100644
--- a/package/boot/apex/patches/140-openwrt_fsg3_armeb_config.patch
+++ b/package/boot/apex/patches/140-openwrt_fsg3_armeb_config.patch
@@ -5,7 +5,7 @@
  # General Setup
  #
 -CONFIG_TARGET_DESCRIPTION="SlugOS FSG3/BE"
-+CONFIG_TARGET_DESCRIPTION="OpenWrt FSG3"
++CONFIG_TARGET_DESCRIPTION="LEDE FSG3"
  CONFIG_CROSS_COMPILE=""
  CONFIG_AEABI=y
  CONFIG_CC_OPTIMIZE_FOR_SIZE=y
diff --git a/package/boot/uboot-ar71xx/Makefile b/package/boot/uboot-ar71xx/Makefile
index 7c4bb6c..3f84279 100644
--- a/package/boot/uboot-ar71xx/Makefile
+++ b/package/boot/uboot-ar71xx/Makefile
@@ -59,7 +59,7 @@ endef
 ifdef BUILD_VARIANT
 $(eval $(call uboot/$(BUILD_VARIANT)))
 UBOOT_CONFIG:=$(if $(CONFIG),$(CONFIG),$(BUILD_VARIANT))
-UBOOT_IMAGE:=$(if $(IMAGE),$(IMAGE),openwrt-$(BOARD)-$(BUILD_VARIANT)-u-boot.bin)
+UBOOT_IMAGE:=$(if $(IMAGE),$(IMAGE),lede-$(BOARD)-$(BUILD_VARIANT)-u-boot.bin)
 endif
 
 define Build/Prepare
@@ -86,7 +86,7 @@ endef
 endef
 
 $(foreach u,$(UBOOTS), \
-	$(eval $(call Package/uboot/install/template,$(u),openwrt-$(BOARD)-$(SUBTARGET)-$(u)-u-boot.bin)) \
+	$(eval $(call Package/uboot/install/template,$(u),lede-$(BOARD)-$(SUBTARGET)-$(u)-u-boot.bin)) \
 )
 
 $(foreach u,$(UBOOTS), \
diff --git a/package/boot/uboot-imx6/Makefile b/package/boot/uboot-imx6/Makefile
index 1e92623..5eb658a 100644
--- a/package/boot/uboot-imx6/Makefile
+++ b/package/boot/uboot-imx6/Makefile
@@ -101,7 +101,7 @@ endef
 ifdef BUILD_VARIANT
 $(eval $(call uboot/$(BUILD_VARIANT)))
 UBOOT_CONFIG:=$(if $(CONFIG),$(CONFIG),$(BUILD_VARIANT))
-UBOOT_IMAGE:=$(if $(IMAGE),$(IMAGE),openwrt-$(BOARD)-$(BUILD_VARIANT)-u-boot.bin)
+UBOOT_IMAGE:=$(if $(IMAGE),$(IMAGE),lede-$(BOARD)-$(BUILD_VARIANT)-u-boot.bin)
 endif
 
 define Build/Configure
@@ -118,7 +118,7 @@ define Package/uboot/install/default
 	$(INSTALL_DIR) $(BIN_DIR)/uboot-$(BOARD)-$(1)
 	$(CP) \
 		$(PKG_BUILD_DIR)/u-boot.imx \
-		$(BIN_DIR)/uboot-$(BOARD)-$(1)/openwrt-$(BOARD)-$(1)-u-boot.imx
+		$(BIN_DIR)/uboot-$(BOARD)-$(1)/lede-$(BOARD)-$(1)-u-boot.imx
 endef
 
 define Package/uboot/install/template
diff --git a/package/boot/uboot-kirkwood/Makefile b/package/boot/uboot-kirkwood/Makefile
index 89caaf1..1bd9a67 100644
--- a/package/boot/uboot-kirkwood/Makefile
+++ b/package/boot/uboot-kirkwood/Makefile
@@ -112,18 +112,18 @@ define Build/Compile
 		CROSS_COMPILE=$(TARGET_CROSS)
 	mkimage -A $(ARCH) -O linux -T kernel -C none \
 		-a 0x600000 -e 0x600000 \
-		-n 'OpenWrt Das U-Boot uImage' \
+		-n 'LEDE Das U-Boot uImage' \
 		-d $(PKG_BUILD_DIR)/u-boot.bin $(PKG_BUILD_DIR)/u-boot.img
 endef
 
 define Package/uboot/install/default
 	$(INSTALL_DIR) $(BIN_DIR)/uboot-$(BOARD)-$(1)
 	$(CP) $(PKG_BUILD_DIR)/u-boot.bin \
-		$(BIN_DIR)/uboot-$(BOARD)-$(1)/openwrt-$(BOARD)-$(1)-u-boot.bin
+		$(BIN_DIR)/uboot-$(BOARD)-$(1)/lede-$(BOARD)-$(1)-u-boot.bin
 	$(CP) $(PKG_BUILD_DIR)/u-boot.kwb \
-		$(BIN_DIR)/uboot-$(BOARD)-$(1)/openwrt-$(BOARD)-$(1)-u-boot.kwb
+		$(BIN_DIR)/uboot-$(BOARD)-$(1)/lede-$(BOARD)-$(1)-u-boot.kwb
 	$(CP) $(PKG_BUILD_DIR)/u-boot.img \
-		$(BIN_DIR)/uboot-$(BOARD)-$(1)/openwrt-$(BOARD)-$(1)-u-boot.img
+		$(BIN_DIR)/uboot-$(BOARD)-$(1)/lede-$(BOARD)-$(1)-u-boot.img
 	$(INSTALL_DIR) $(BIN_DIR)/u-boot-kwboot/
 	$(CP) $(PKG_BUILD_DIR)/tools/kwboot \
 		$(BIN_DIR)/u-boot-kwboot/
diff --git a/package/boot/uboot-lantiq/Makefile b/package/boot/uboot-lantiq/Makefile
index 99b101f..946bd53 100644
--- a/package/boot/uboot-lantiq/Makefile
+++ b/package/boot/uboot-lantiq/Makefile
@@ -355,7 +355,7 @@ endef
 define Package/uboot/install/default
 	$(CP) \
 		$(PKG_BUILD_DIR)/$(2) \
-		$(BIN_DIR)/uboot-$(BOARD)-$(1)/openwrt-$(BOARD)-$(1)-u-boot.img
+		$(BIN_DIR)/uboot-$(BOARD)-$(1)/lede-$(BOARD)-$(1)-u-boot.img
 endef
 
 define Package/uboot/install/uart
@@ -364,7 +364,7 @@ define Package/uboot/install/uart
 		> $(PKG_BUILD_DIR)/ddr_settings
 	perl $(PKG_BUILD_DIR)/tools/gct.pl \
 		$(PKG_BUILD_DIR)/ddr_settings $(PKG_BUILD_DIR)/u-boot.srec \
-		$(BIN_DIR)/uboot-$(BOARD)-$(1)/openwrt-$(BOARD)-$(1)-u-boot.asc
+		$(BIN_DIR)/uboot-$(BOARD)-$(1)/lede-$(BOARD)-$(1)-u-boot.asc
  endef
 
 define Package/uboot/install/template
diff --git a/package/boot/uboot-lantiq/patches/0017-tools-add-some-helper-tools-for-Lantiq-SoCs.patch b/package/boot/uboot-lantiq/patches/0017-tools-add-some-helper-tools-for-Lantiq-SoCs.patch
index ef6666a..295e435 100644
--- a/package/boot/uboot-lantiq/patches/0017-tools-add-some-helper-tools-for-Lantiq-SoCs.patch
+++ b/package/boot/uboot-lantiq/patches/0017-tools-add-some-helper-tools-for-Lantiq-SoCs.patch
@@ -290,7 +290,7 @@ Signed-off-by: Daniel Schwierzeck <daniel.schwierzeck@gmail.com>
 +# Copyright (C) 2011-2013 Luka Perkov <luka@openwrt.org>
 +#
 +# Usage:
-+# mips-openwrt-linux-objdump -EB -b binary -m mips:isa32r2 -D YOUR_IMAGE_DUMP | awk -f lantiq_ram_extract_magic.awk
++# mips-lede-linux-objdump -EB -b binary -m mips:isa32r2 -D YOUR_IMAGE_DUMP | awk -f lantiq_ram_extract_magic.awk
 +#
 +# SPDX-License-Identifier:	GPL-2.0+
 +#
diff --git a/package/boot/uboot-mvebu/Makefile b/package/boot/uboot-mvebu/Makefile
index 170da6d..93532b3 100644
--- a/package/boot/uboot-mvebu/Makefile
+++ b/package/boot/uboot-mvebu/Makefile
@@ -69,7 +69,7 @@ endef
 define Package/uboot/install/default
 	$(INSTALL_DIR) $(BIN_DIR)/uboot-$(BOARD)-$(1)
 	$(CP) $(PKG_BUILD_DIR)/u-boot-spl.kwb \
-		$(BIN_DIR)/uboot-$(BOARD)-$(1)/openwrt-$(BOARD)-$(1)-u-boot-spl.kwb
+		$(BIN_DIR)/uboot-$(BOARD)-$(1)/lede-$(BOARD)-$(1)-u-boot-spl.kwb
 	$(INSTALL_DIR) $(BIN_DIR)/u-boot-kwboot/
 	$(CP) $(PKG_BUILD_DIR)/tools/kwboot \
 		$(BIN_DIR)/u-boot-kwboot/
diff --git a/package/boot/uboot-omap/Makefile b/package/boot/uboot-omap/Makefile
index 5441baf..f02bb24 100644
--- a/package/boot/uboot-omap/Makefile
+++ b/package/boot/uboot-omap/Makefile
@@ -68,7 +68,7 @@ endef
 ifdef BUILD_VARIANT
 $(eval $(call uboot/$(BUILD_VARIANT)))
 UBOOT_CONFIG:=$(if $(CONFIG),$(CONFIG),$(BUILD_VARIANT))
-UBOOT_IMAGE:=$(if $(IMAGE),$(IMAGE),openwrt-$(BOARD)-$(BUILD_VARIANT)-u-boot.img)
+UBOOT_IMAGE:=$(if $(IMAGE),$(IMAGE),lede-$(BOARD)-$(BUILD_VARIANT)-u-boot.img)
 endif
 
 define Build/Configure
diff --git a/package/boot/uboot-oxnas/Makefile b/package/boot/uboot-oxnas/Makefile
index 825907b..851a085 100644
--- a/package/boot/uboot-oxnas/Makefile
+++ b/package/boot/uboot-oxnas/Makefile
@@ -58,7 +58,7 @@ endef
 ifdef BUILD_VARIANT
 $(eval $(call uboot/$(BUILD_VARIANT)))
 UBOOT_CONFIG:=$(if $(CONFIG),$(CONFIG),$(BUILD_VARIANT))
-UBOOT_IMAGE:=$(if $(IMAGE),$(IMAGE),openwrt-$(BOARD)-$(BUILD_VARIANT)-u-boot.bin)
+UBOOT_IMAGE:=$(if $(IMAGE),$(IMAGE),lede-$(BOARD)-$(BUILD_VARIANT)-u-boot.bin)
 endif
 
 define Build/Prepare
@@ -81,7 +81,7 @@ endef
 define Package/uboot/install/default
 	$(INSTALL_DIR) $(BIN_DIR)
 	$(CP) $(PKG_BUILD_DIR)/u-boot.bin \
-		$(BIN_DIR)/openwrt-$(BOARD)-$(1)-u-boot.bin
+		$(BIN_DIR)/lede-$(BOARD)-$(1)-u-boot.bin
 	$(CP) $(PKG_BUILD_DIR)/u-boot.bin \
 		$(KERNEL_BUILD_DIR)/u-boot.bin
 endef
diff --git a/package/boot/uboot-pxa/Makefile b/package/boot/uboot-pxa/Makefile
index 9dae1af..c7304bc 100644
--- a/package/boot/uboot-pxa/Makefile
+++ b/package/boot/uboot-pxa/Makefile
@@ -56,7 +56,7 @@ endef
 ifdef BUILD_VARIANT
 $(eval $(call uboot/$(BUILD_VARIANT)))
 UBOOT_CONFIG:=$(if $(CONFIG),$(CONFIG),$(BUILD_VARIANT))
-UBOOT_IMAGE:=$(if $(IMAGE),$(IMAGE),openwrt-$(BOARD)-$(BUILD_VARIANT)-u-boot.bin)
+UBOOT_IMAGE:=$(if $(IMAGE),$(IMAGE),lede-$(BOARD)-$(BUILD_VARIANT)-u-boot.bin)
 endif
 
 define Build/Configure
@@ -73,7 +73,7 @@ endef
 define Package/uboot/install/default
 	$(INSTALL_DIR) $(BIN_DIR)
 	$(CP) $(PKG_BUILD_DIR)/u-boot.bin \
-		$(BIN_DIR)/openwrt-$(BOARD)-$(1)-u-boot.bin
+		$(BIN_DIR)/lede-$(BOARD)-$(1)-u-boot.bin
 endef
 
 define Package/uboot/install/template
diff --git a/package/boot/uboot-sunxi/Makefile b/package/boot/uboot-sunxi/Makefile
index d411072..af46aa0 100644
--- a/package/boot/uboot-sunxi/Makefile
+++ b/package/boot/uboot-sunxi/Makefile
@@ -138,7 +138,7 @@ endef
 ifdef BUILD_VARIANT
 $(eval $(call uboot/$(BUILD_VARIANT)))
 UBOOT_CONFIG:=$(if $(CONFIG),$(CONFIG),$(BUILD_VARIANT))
-UBOOT_IMAGE:=$(if $(IMAGE),$(IMAGE),openwrt-$(BOARD)-$(BUILD_VARIANT)-u-boot.bin)
+UBOOT_IMAGE:=$(if $(IMAGE),$(IMAGE),lede-$(BOARD)-$(BUILD_VARIANT)-u-boot.bin)
 endif
 
 # check if any specialized uEnv bootconfig is required
diff --git a/package/boot/uboot-xburst/Makefile b/package/boot/uboot-xburst/Makefile
index 4a701f8..babff8a 100644
--- a/package/boot/uboot-xburst/Makefile
+++ b/package/boot/uboot-xburst/Makefile
@@ -58,7 +58,7 @@ endef
 ifdef BUILD_VARIANT
 $(eval $(call uboot/$(BUILD_VARIANT)))
 UBOOT_CONFIG:=$(if $(CONFIG),$(CONFIG),$(BUILD_VARIANT))
-UBOOT_IMAGE:=$(if $(IMAGE),$(IMAGE),openwrt-$(BOARD)-$(BUILD_VARIANT)-u-boot.bin)
+UBOOT_IMAGE:=$(if $(IMAGE),$(IMAGE),lede-$(BOARD)-$(BUILD_VARIANT)-u-boot.bin)
 endif
 
 define Build/Configure
@@ -79,7 +79,7 @@ endef
 endef
 
 $(foreach u,$(UBOOTS), \
-	$(eval $(call Package/uboot/install/template,$(u),openwrt-$(BOARD)-$(u)-u-boot.bin)) \
+	$(eval $(call Package/uboot/install/template,$(u),lede-$(BOARD)-$(u)-u-boot.bin)) \
 )
 
 $(foreach u,$(UBOOTS), \
diff --git a/package/boot/uboot-zynq/Makefile b/package/boot/uboot-zynq/Makefile
index 412415b..18c6949 100644
--- a/package/boot/uboot-zynq/Makefile
+++ b/package/boot/uboot-zynq/Makefile
@@ -71,7 +71,7 @@ endef
 ifdef BUILD_VARIANT
 $(eval $(call uboot/$(BUILD_VARIANT)))
 UBOOT_CONFIG:=$(if $(CONFIG),$(CONFIG),$(BUILD_VARIANT))
-UBOOT_IMAGE:=$(if $(IMAGE),$(IMAGE),openwrt-$(BOARD)-$(BUILD_VARIANT)-u-boot.bin)
+UBOOT_IMAGE:=$(if $(IMAGE),$(IMAGE),lede-$(BOARD)-$(BUILD_VARIANT)-u-boot.bin)
 endif
 
 define Build/Configure
diff --git a/package/libs/openssl/Makefile b/package/libs/openssl/Makefile
index 3baf98c..7c9c077 100644
--- a/package/libs/openssl/Makefile
+++ b/package/libs/openssl/Makefile
@@ -121,16 +121,16 @@ ifndef CONFIG_OPENSSL_HARDWARE_SUPPORT
 endif
 
 ifeq ($(CONFIG_x86_64),y)
-  OPENSSL_TARGET:=linux-x86_64-openwrt
+  OPENSSL_TARGET:=linux-x86_64-lede
   OPENSSL_MAKEFLAGS += LIBDIR=lib
 else
   OPENSSL_OPTIONS+=no-sse2
   ifeq ($(CONFIG_mips)$(CONFIG_mipsel),y)
-    OPENSSL_TARGET:=linux-mips-openwrt
+    OPENSSL_TARGET:=linux-mips-lede
 #  else ifeq ($(CONFIG_arm)$(CONFIG_armeb),y)
-#    OPENSSL_TARGET:=linux-armv4-openwrt
+#    OPENSSL_TARGET:=linux-armv4-lede
   else
-    OPENSSL_TARGET:=linux-generic-openwrt
+    OPENSSL_TARGET:=linux-generic-lede
     OPENSSL_OPTIONS+=no-perlasm
   endif
 endif
diff --git a/package/libs/openssl/patches/110-optimize-for-size.patch b/package/libs/openssl/patches/110-optimize-for-size.patch
index 1721842..4041f15 100644
--- a/package/libs/openssl/patches/110-optimize-for-size.patch
+++ b/package/libs/openssl/patches/110-optimize-for-size.patch
@@ -5,10 +5,10 @@
  "linux-alpha+bwx-ccc","ccc:-fast -readonly_strings -DL_ENDIAN::-D_REENTRANT:::SIXTY_FOUR_BIT_LONG RC4_CHAR RC4_CHUNK DES_INT DES_PTR DES_RISC1 DES_UNROLL:${alpha_asm}",
  
 +# OpenWrt targets
-+"linux-armv4-openwrt","gcc:-DTERMIOS \$(OPENWRT_OPTIMIZATION_FLAGS) -fomit-frame-pointer -Wall::-D_REENTRANT::-ldl:BN_LLONG RC4_CHAR RC4_CHUNK DES_INT DES_UNROLL BF_PTR:${armv4_asm}:dlfcn:linux-shared:-fPIC::.so.\$(SHLIB_MAJOR).\$(SHLIB_MINOR)",
-+"linux-x86_64-openwrt",	"gcc:-m64 -DL_ENDIAN -DTERMIOS \$(OPENWRT_OPTIMIZATION_FLAGS) -fomit-frame-pointer -Wall::-D_REENTRANT::-ldl:SIXTY_FOUR_BIT_LONG RC4_CHUNK DES_INT DES_UNROLL:${x86_64_asm}:elf:dlfcn:linux-shared:-fPIC:-m64:.so.\$(SHLIB_MAJOR).\$(SHLIB_MINOR):::64",
-+"linux-mips-openwrt","gcc:-DTERMIOS \$(OPENWRT_OPTIMIZATION_FLAGS) -fomit-frame-pointer -Wall::-D_REENTRANT::-ldl:BN_LLONG RC4_CHAR RC4_CHUNK DES_INT DES_UNROLL BF_PTR:${mips32_asm}:o32:dlfcn:linux-shared:-fPIC::.so.\$(SHLIB_MAJOR).\$(SHLIB_MINOR)",
-+"linux-generic-openwrt","gcc:-DTERMIOS \$(OPENWRT_OPTIMIZATION_FLAGS) -fomit-frame-pointer -Wall::-D_REENTRANT::-ldl:BN_LLONG RC4_CHAR RC4_CHUNK DES_INT DES_UNROLL BF_PTR:${no_asm}:dlfcn:linux-shared:-fPIC::.so.\$(SHLIB_MAJOR).\$(SHLIB_MINOR)",
++"linux-armv4-lede","gcc:-DTERMIOS \$(OPENWRT_OPTIMIZATION_FLAGS) -fomit-frame-pointer -Wall::-D_REENTRANT::-ldl:BN_LLONG RC4_CHAR RC4_CHUNK DES_INT DES_UNROLL BF_PTR:${armv4_asm}:dlfcn:linux-shared:-fPIC::.so.\$(SHLIB_MAJOR).\$(SHLIB_MINOR)",
++"linux-x86_64-lede",	"gcc:-m64 -DL_ENDIAN -DTERMIOS \$(OPENWRT_OPTIMIZATION_FLAGS) -fomit-frame-pointer -Wall::-D_REENTRANT::-ldl:SIXTY_FOUR_BIT_LONG RC4_CHUNK DES_INT DES_UNROLL:${x86_64_asm}:elf:dlfcn:linux-shared:-fPIC:-m64:.so.\$(SHLIB_MAJOR).\$(SHLIB_MINOR):::64",
++"linux-mips-lede","gcc:-DTERMIOS \$(OPENWRT_OPTIMIZATION_FLAGS) -fomit-frame-pointer -Wall::-D_REENTRANT::-ldl:BN_LLONG RC4_CHAR RC4_CHUNK DES_INT DES_UNROLL BF_PTR:${mips32_asm}:o32:dlfcn:linux-shared:-fPIC::.so.\$(SHLIB_MAJOR).\$(SHLIB_MINOR)",
++"linux-generic-lede","gcc:-DTERMIOS \$(OPENWRT_OPTIMIZATION_FLAGS) -fomit-frame-pointer -Wall::-D_REENTRANT::-ldl:BN_LLONG RC4_CHAR RC4_CHUNK DES_INT DES_UNROLL BF_PTR:${no_asm}:dlfcn:linux-shared:-fPIC::.so.\$(SHLIB_MAJOR).\$(SHLIB_MINOR)",
 +
  # Android: linux-* but without pointers to headers and libs.
  "android","gcc:-mandroid -I\$(ANDROID_DEV)/include -B\$(ANDROID_DEV)/lib -O3 -fomit-frame-pointer -Wall::-D_REENTRANT::-ldl:BN_LLONG RC4_CHAR RC4_CHUNK DES_INT DES_UNROLL BF_PTR:${no_asm}:dlfcn:linux-shared:-fPIC::.so.\$(SHLIB_MAJOR).\$(SHLIB_MINOR)",
diff --git a/package/network/config/qos-scripts/files/usr/lib/qos/generate.sh b/package/network/config/qos-scripts/files/usr/lib/qos/generate.sh
index 285617c..4e3d70b 100755
--- a/package/network/config/qos-scripts/files/usr/lib/qos/generate.sh
+++ b/package/network/config/qos-scripts/files/usr/lib/qos/generate.sh
@@ -20,7 +20,7 @@ add_insmod() {
 }
 
 [ -e /etc/config/network ] && {
-	# only try to parse network config on openwrt
+	# only try to parse network config on lede
 
 	find_ifname() {(
 		reset_cb
diff --git a/package/network/services/hostapd/files/wpa_supplicant-p2p.config b/package/network/services/hostapd/files/wpa_supplicant-p2p.config
index 1c307d0..eb98608 100644
--- a/package/network/services/hostapd/files/wpa_supplicant-p2p.config
+++ b/package/network/services/hostapd/files/wpa_supplicant-p2p.config
@@ -30,7 +30,7 @@
 #LIBS += -L/opt/brcm/hndtools-mipsel-uclibc-0.9.19/lib -lssl
 ###############################################################################
 
-#### openwrt (e.g., for Linksys WRT54G) #######################################
+#### lede (e.g., for Linksys WRT54G) #######################################
 #CC=mipsel-uclibc-gcc
 #CC=/opt/brcm/hndtools-mipsel-uclibc/bin/mipsel-uclibc-gcc
 #CFLAGS += -Os
diff --git a/package/network/services/lldpd/patches/100-os-release.patch b/package/network/services/lldpd/patches/100-os-release.patch
index a906f39..56e0b2c 100644
--- a/package/network/services/lldpd/patches/100-os-release.patch
+++ b/package/network/services/lldpd/patches/100-os-release.patch
@@ -7,7 +7,7 @@ Index: lldpd-0.7.15/src/daemon/lldpd.c
  	}
  	if (!fp) {
 +		log_debug("localchassis", "could not open /usr/lib/os-release");
-+		fp = fopen("/etc/openwrt_release", "r");
++		fp = fopen("/etc/lede_release", "r");
 +	}
 +	if (!fp) {
  		log_info("localchassis",
diff --git a/rules.mk b/rules.mk
index 12a79ba..5cee290 100644
--- a/rules.mk
+++ b/rules.mk
@@ -104,8 +104,8 @@ ifeq ($(CONFIG_EXTERNAL_TOOLCHAIN),)
   GCCV:=$(call qstrip,$(CONFIG_GCC_VERSION))
   LIBC:=$(call qstrip,$(CONFIG_LIBC))
   LIBCV:=$(call qstrip,$(CONFIG_LIBC_VERSION))
-  REAL_GNU_TARGET_NAME=$(OPTIMIZE_FOR_CPU)-openwrt-linux$(if $(TARGET_SUFFIX),-$(TARGET_SUFFIX))
-  GNU_TARGET_NAME=$(OPTIMIZE_FOR_CPU)-openwrt-linux
+  REAL_GNU_TARGET_NAME=$(OPTIMIZE_FOR_CPU)-lede-linux$(if $(TARGET_SUFFIX),-$(TARGET_SUFFIX))
+  GNU_TARGET_NAME=$(OPTIMIZE_FOR_CPU)-lede-linux
   DIR_SUFFIX:=_$(LIBC)-$(LIBCV)$(if $(CONFIG_arm),_eabi)
   BIN_DIR:=$(BIN_DIR)$(if $(CONFIG_USE_MUSL),,-$(LIBC))
   TARGET_DIR_NAME = target-$(ARCH)$(ARCH_SUFFIX)$(DIR_SUFFIX)$(if $(BUILD_SUFFIX),_$(BUILD_SUFFIX))
diff --git a/scripts/checkpatch.pl b/scripts/checkpatch.pl
index 9858e62..1b9c236 100755
--- a/scripts/checkpatch.pl
+++ b/scripts/checkpatch.pl
@@ -11,7 +11,7 @@ use strict;
 my $P = $0;
 $P =~ s@.*/@@g;
 
-my $V = '0.32-openwrt';
+my $V = '0.32-lede';
 
 use Getopt::Long qw(:config no_auto_abbrev);
 
@@ -160,14 +160,14 @@ if ($terse) {
 
 if ($tree) {
 	if (defined $root) {
-		if (!top_of_openwrt_tree($root)) {
+		if (!top_of_lede_tree($root)) {
 			die "$P: $root: --root does not point at a valid tree\n";
 		}
 	} else {
-		if (top_of_openwrt_tree('.')) {
+		if (top_of_lede_tree('.')) {
 			$root = '.';
 		} elsif ($0 =~ m@(.*)/scripts/[^/]*$@ &&
-						top_of_openwrt_tree($1)) {
+						top_of_lede_tree($1)) {
 			$root = $1;
 		}
 	}
@@ -386,7 +386,7 @@ for my $filename (@ARGV) {
 
 exit($exit);
 
-sub top_of_openwrt_tree {
+sub top_of_lede_tree {
 	my ($root) = @_;
 
 	my @tree_check = (
diff --git a/scripts/combined-image.sh b/scripts/combined-image.sh
index 5472b2c..ba16c6b 100644
--- a/scripts/combined-image.sh
+++ b/scripts/combined-image.sh
@@ -7,7 +7,7 @@ BLKSZ=65536
 	exit 1
 }
 
-IMAGE=${3:-openwrt-combined.img}
+IMAGE=${3:-lede-combined.img}
 
 # Make sure provided images are 64k aligned.
 kern="${IMAGE}.kernel"
diff --git a/scripts/symlink-tree.sh b/scripts/symlink-tree.sh
index e44ebda..7ba5066 100755
--- a/scripts/symlink-tree.sh
+++ b/scripts/symlink-tree.sh
@@ -1,5 +1,5 @@
 #!/usr/bin/env bash
-# Create a new openwrt tree with symlinks pointing at the current tree
+# Create a new lede tree with symlinks pointing at the current tree
 # Usage: ./scripts/symlink-tree.sh <destination>
 
 FILES="
diff --git a/target/linux/adm5120/image/router_le.mk b/target/linux/adm5120/image/router_le.mk
index 1e3d7f7..1f47e08 100644
--- a/target/linux/adm5120/image/router_le.mk
+++ b/target/linux/adm5120/image/router_le.mk
@@ -89,7 +89,7 @@ define Image/Build/Cellvision2
 	dd if=$(KDIR)/loader-$(2).gz of=$(call imgname,$(1),$(2)).bin bs=64k conv=sync
 	cat $(call imgname,$(1),$(2)).trx >> $(call imgname,$(1),$(2)).bin
 	echo -ne '\x14\x07\x24\x06$(2)' | dd bs=14 count=1 conv=sync >> $(call imgname,$(1),$(2)).bin
-	echo -ne 'OpenWrt\x00\x00\x00' >> $(call imgname,$(1),$(2)).bin
+	echo -ne 'LEDE\x00\x00\x00' >> $(call imgname,$(1),$(2)).bin
 endef
 
 define Image/Build/MyLoader
diff --git a/target/linux/adm5120/rb1xx/base-files/sbin/wget2nand b/target/linux/adm5120/rb1xx/base-files/sbin/wget2nand
index f7e0a09..7de4609 100755
--- a/target/linux/adm5120/rb1xx/base-files/sbin/wget2nand
+++ b/target/linux/adm5120/rb1xx/base-files/sbin/wget2nand
@@ -52,9 +52,9 @@ echo "Erasing existing files..."
 rm -rf /tmp/wget2nand-rootfs/*
 
 echo "Copying filesystem..."
-( wget -O - $url/openwrt-adm5120-rb1xx-rootfs.tar.gz) | ( cd /tmp/wget2nand-rootfs/; tar xvz )
+( wget -O - $url/lede-adm5120-rb1xx-rootfs.tar.gz) | ( cd /tmp/wget2nand-rootfs/; tar xvz )
 # RouterBOOT is looking for a kernel named "kernel"
-wget -O /tmp/wget2nand-kernel/kernel $url/openwrt-adm5120-rb1xx-vmlinux.elf
+wget -O /tmp/wget2nand-kernel/kernel $url/lede-adm5120-rb1xx-vmlinux.elf
 
 chmod +x /tmp/wget2nand-kernel/kernel
 
diff --git a/target/linux/adm8668/image/lzma-loader/src/Makefile b/target/linux/adm8668/image/lzma-loader/src/Makefile
index 998e390..b4dc0e6 100644
--- a/target/linux/adm8668/image/lzma-loader/src/Makefile
+++ b/target/linux/adm8668/image/lzma-loader/src/Makefile
@@ -9,7 +9,7 @@ RAMSIZE		= 0x00800000		# 8MB
 LOADADDR	= 0x80400000		# RAM start + 4M
 KERNEL_ENTRY	= 0x80002000
 
-CROSS_COMPILE = mipsel-openwrt-linux-
+CROSS_COMPILE = mipsel-lede-linux-
 
 OBJCOPY:= $(CROSS_COMPILE)objcopy -O binary -R .reginfo -R .note -R .comment -R .mdebug -S
 CFLAGS := -I./include -fno-builtin -Os -G 0 -ffunction-sections -mno-abicalls -fno-pic -mabi=32 -march=mips32 -Wa,-32 -Wa,-march=mips32 -Wa,-mips32 -Wa,--trap -Wall -DRAMSTART=${RAMSTART} -DRAMSIZE=${RAMSIZE} -DKERNEL_ENTRY=${KERNEL_ENTRY}
diff --git a/target/linux/ar71xx/base-files/sbin/wget2nand b/target/linux/ar71xx/base-files/sbin/wget2nand
index 8175a9e..5b83857 100755
--- a/target/linux/ar71xx/base-files/sbin/wget2nand
+++ b/target/linux/ar71xx/base-files/sbin/wget2nand
@@ -27,8 +27,8 @@ url=$1
         exit 1
 }
 
-url_kernel=$url/openwrt-ar71xx-mikrotik-vmlinux-lzma.elf
-url_rootfs=$url/openwrt-ar71xx-mikrotik-rootfs.tar.gz
+url_kernel=$url/lede-ar71xx-mikrotik-vmlinux-lzma.elf
+url_rootfs=$url/lede-ar71xx-mikrotik-rootfs.tar.gz
 
 mtd_kernel="$(find_mtd_part 'kernel')"
 mtd_rootfs="$(find_mtd_part 'rootfs')"
diff --git a/target/linux/ar71xx/image/Makefile b/target/linux/ar71xx/image/Makefile
index 3bf005f..cd879fd 100644
--- a/target/linux/ar71xx/image/Makefile
+++ b/target/linux/ar71xx/image/Makefile
@@ -30,7 +30,7 @@ define Build/netgear-squashfs
 		-A mips -O linux -T filesystem -C none \
 		-M $(NETGEAR_KERNEL_MAGIC) \
 		-a 0xbf070000 -e 0xbf070000 \
-		-n 'MIPS OpenWrt Linux-$(LINUX_VERSION)' \
+		-n 'MIPS LEDE Linux-$(LINUX_VERSION)' \
 		-d $@.squashfs $@
 	rm -rf $@.squashfs $@.fs
 endef
@@ -49,7 +49,7 @@ endef
 # -X reserve <size> bytes in the firmware image (hexval prefixed with 0x)
 define Build/mktplinkfw
 	-$(STAGING_DIR_HOST)/bin/mktplinkfw \
-		-H $(TPLINK_HWID) -W $(TPLINK_HWREV) -F $(TPLINK_FLASHLAYOUT) -N OpenWrt -V $(REVISION) \
+		-H $(TPLINK_HWID) -W $(TPLINK_HWREV) -F $(TPLINK_FLASHLAYOUT) -N LEDE -V $(REVISION) \
 		-m $(TPLINK_HEADER_VERSION) \
 		-k $(word 1,$^) \
 		-r $@ \
@@ -65,7 +65,7 @@ endef
 # -c combined image
 define Build/mktplinkfw-initramfs
 	$(STAGING_DIR_HOST)/bin/mktplinkfw \
-		-H $(TPLINK_HWID) -W $(TPLINK_HWREV) -F $(TPLINK_FLASHLAYOUT) -N OpenWrt -V $(REVISION) $(1) \
+		-H $(TPLINK_HWID) -W $(TPLINK_HWREV) -F $(TPLINK_FLASHLAYOUT) -N LEDE -V $(REVISION) $(1) \
 		-m $(TPLINK_HEADER_VERSION) \
 		-k $@ \
 		-o $@.new \
@@ -130,7 +130,7 @@ DEVICE_VARS += TPLINK_HWID TPLINK_HWREV TPLINK_FLASHLAYOUT TPLINK_HEADER_VERSION
 # routerboard creates partitions out of the ubnt header
 define Build/mkubntimage
 	$(STAGING_DIR_HOST)/bin/mkfwimage \
-		-B $(UBNT_BOARD) -v $(UBNT_TYPE).$(UBNT_CHIP).v6.0.0-OpenWrt-$(REVISION) \
+		-B $(UBNT_BOARD) -v $(UBNT_TYPE).$(UBNT_CHIP).v6.0.0-LEDE-$(REVISION) \
 		-k $(word 1,$^) \
 		-r $@ \
 		-o $@
@@ -142,7 +142,7 @@ define Build/mkubntimage-split
 	dd if=$@ of=$@.old1 bs=1024k count=1
 	dd if=$@ of=$@.old2 bs=1024k skip=1
 	$(STAGING_DIR_HOST)/bin/mkfwimage \
-		-B $(UBNT_BOARD) -v $(UBNT_TYPE).$(UBNT_CHIP).v6.0.0-OpenWrt-$(REVISION) \
+		-B $(UBNT_BOARD) -v $(UBNT_TYPE).$(UBNT_CHIP).v6.0.0-LEDE-$(REVISION) \
 		-k $@.old1 \
 		-r $@.old2 \
 		-o $@
@@ -151,7 +151,7 @@ endef
 
 define Build/mkubntimage2
 	$(STAGING_DIR_HOST)/bin/mkfwimage2 -f 0x9f000000 \
-		-v $(UBNT_TYPE).$(UBNT_CHIP).v6.0.0-OpenWrt-$(REVISION) \
+		-v $(UBNT_TYPE).$(UBNT_CHIP).v6.0.0-LEDE-$(REVISION) \
 		-p jffs2:0x50000:0xf60000:0:0:$@ \
 		-o $@.new
 	@mv $@.new $@
@@ -1450,7 +1450,7 @@ ifneq ($(SUBTARGET),mikrotik)
 # $(4): output file.
 define MkuImage
 	mkimage -A mips -O linux -T kernel -a 0x80060000 -C $(1) $(2) \
-		-e 0x80060000 -n 'MIPS OpenWrt Linux-$(LINUX_VERSION)' \
+		-e 0x80060000 -n 'MIPS LEDE Linux-$(LINUX_VERSION)' \
 		-d $(3) $(4)
 endef
 
@@ -1892,11 +1892,11 @@ define Image/Build/Belkin
 	$(eval rootsize=$(call mtdpartsize,rootfs,$(4)))
 	$(call Sysupgrade/RKuImage,$(1),$(2),$(kernsize),$(rootsize))
 	if [ -e "$(call sysupname,$(1),$(2))" ]; then \
-		edimax_fw_header -m $(5) -v "OpenWrt$(REVISION)" \
+		edimax_fw_header -m $(5) -v "LEDE$(REVISION)" \
 			-n "uImage" \
 			-i $(KDIR_TMP)/vmlinux-$(2).uImage \
 			-o $(KDIR_TMP)/$(2)-uImage; \
-		edimax_fw_header -m $(5) -v "OpenWrt$(REVISION)" \
+		edimax_fw_header -m $(5) -v "LEDE$(REVISION)" \
 			-n "rootfs" \
 			-i $(KDIR)/root.$(1) \
 			-o $(KDIR_TMP)/$(2)-rootfs; \
@@ -1930,7 +1930,7 @@ Image/Build/EnGenius/initramfs=$(call MkuImageLzma/initramfs,$(2),$(3) $(4))
 define MkuImageHiWiFi
 	# Field ih_name needs to start with "tw150v1"
 	mkimage -A mips -O linux -T kernel -a 0x80060000 -C $(1) $(2) \
-		-e 0x80060000 -n 'tw150v1 MIPS OpenWrt Linux-$(LINUX_VERSION)' \
+		-e 0x80060000 -n 'tw150v1 MIPS LEDE Linux-$(LINUX_VERSION)' \
 		-d $(3) $(4)
 endef
 
@@ -2059,12 +2059,12 @@ Image/Build/Senao/initramfs=$(call MkuImageLzma/initramfs,$(2),$(3) $(4))
 
 define Image/Build/Senao
 	mkdir -p $(KDIR_TMP)/$(2)/
-	touch $(KDIR_TMP)/$(2)/FWINFO-OpenWrt-$(REVISION)-$(2)
+	touch $(KDIR_TMP)/$(2)/FWINFO-LEDE-$(REVISION)-$(2)
 	-$(CP) ./$(2)/* $(KDIR_TMP)/$(2)/
 	dd if=$(KDIR_TMP)/vmlinux-$(2).uImage \
-		of=$(KDIR_TMP)/$(2)/openwrt-senao-$(2)-uImage-lzma.bin bs=64k conv=sync
+		of=$(KDIR_TMP)/$(2)/lede-senao-$(2)-uImage-lzma.bin bs=64k conv=sync
 	dd if=$(KDIR)/root.$(1) \
-		of=$(KDIR_TMP)/$(2)/openwrt-senao-$(2)-root.$(1) bs=64k conv=sync
+		of=$(KDIR_TMP)/$(2)/chsorewrt-senao-$(2)-root.$(1) bs=64k conv=sync
 	( \
 		cd $(KDIR_TMP)/$(2)/;  \
 		$(TAR) -cz -f $(call factoryname,$(1),$(2)) * \
@@ -2125,7 +2125,7 @@ define Image/Build/Netgear/buildkernel
 	) > $(KDIR_TMP)/vmlinux-$(2).uImage.squashfs.tmp2
 	mkimage -A mips -O linux -T filesystem -C none -M $(5) \
 		-a 0xbf070000 -e 0xbf070000 \
-		-n 'MIPS OpenWrt Linux-$(LINUX_VERSION)' \
+		-n 'MIPS LEDE Linux-$(LINUX_VERSION)' \
 		-d $(KDIR_TMP)/vmlinux-$(2).uImage.squashfs.tmp2 \
 		$(KDIR_TMP)/vmlinux-$(2).uImage.squashfs
 endef
@@ -2137,7 +2137,7 @@ define Image/Build/Netgear
 		for r in $(7) ; do \
 			[ -n "$$$$r" ] && dashr="-$$$$r" || dashr= ; \
 			$(STAGING_DIR_HOST)/bin/mkdniimg \
-				-B $(6) -v OpenWrt.$(REVISION) -r "$$$$r" $(8) \
+				-B $(6) -v LEDE.$(REVISION) -r "$$$$r" $(8) \
 				-i $(call sysupname,$(1),$(2)) \
 				-o $(call imgname,$(1),$(2))-factory$$$$dashr.img; \
 		done; \
@@ -2174,7 +2174,7 @@ define Image/Build/NetgearNAND/buildkernel
 	dd if=/dev/zero of=$(KDIR_TMP)/fakeroot-$(2) bs=131072 count=1
 	mkimage -A mips -O linux -T filesystem -C none \
 		-a 0xbf070000 -e 0xbf070000 \
-		-n 'MIPS OpenWrt fakeroot' \
+		-n 'MIPS LEDE fakeroot' \
 		-d $(KDIR_TMP)/fakeroot-$(2) \
 		-M $(5) \
 		$(KDIR_TMP)/fakeroot-$(2).uImage
@@ -2205,7 +2205,7 @@ define Image/Build/NetgearNAND
 		dd if=$(KDIR_TMP)/$(2)-root.ubi \
 	) > $(imageraw)
 	$(STAGING_DIR_HOST)/bin/mkdniimg \
-		-B $(6) -v OpenWrt.$(REVISION) -r "$$$$r" $(8) \
+		-B $(6) -v LEDE.$(REVISION) -r "$$$$r" $(8) \
 		-i $(imageraw) \
 		-o $(call imgname,ubi,$(2))-factory.img
 
diff --git a/target/linux/ar71xx/image/lzma-loader/src/Makefile b/target/linux/ar71xx/image/lzma-loader/src/Makefile
index 5f10bdb..290516e 100644
--- a/target/linux/ar71xx/image/lzma-loader/src/Makefile
+++ b/target/linux/ar71xx/image/lzma-loader/src/Makefile
@@ -4,7 +4,7 @@
 #
 # Copyright (C) 2011 Gabor Juhos <juhosg@openwrt.org>
 #
-# Some parts of this file was based on the OpenWrt specific lzma-loader
+# Some parts of this file was based on the LEDE specific lzma-loader
 # for the BCM47xx and ADM5120 based boards:
 #	Copyright (C) 2004 Manuel Novoa III (mjn3@codepoet.org)
 #	Copyright (C) 2005 Mineharu Takahara <mtakahar@yahoo.com>
diff --git a/target/linux/arm64/README b/target/linux/arm64/README
index 0328ca1..08e97fe 100644
--- a/target/linux/arm64/README
+++ b/target/linux/arm64/README
@@ -1,13 +1,13 @@
 This multi-platform ARMv8 target can be used either with ARM Ltd.'s Foundation_V8
 fast-model doing the following:
 
-Foundation_v8 --image bin/arm64-eglibc/openwrt-arm64-vexpress-foundation.axf
+Foundation_v8 --image bin/arm64-eglibc/lede-arm64-vexpress-foundation.axf
 
 or you can also use QEMU:
 
 qemu-system-aarch64 -machine virt -cpu cortex-a57 -machine type=virt -nographic \
 	-smp 1 -m 2048 \
-	-kernel bin/arm64-eglibc/openwrt-arm64-qemu-virt-initramfs.Image \
+	-kernel bin/arm64-eglibc/lede-arm64-qemu-virt-initramfs.Image \
 	--append "console=ttyAMA0"
 
 and enjoy the system booting.
diff --git a/target/linux/at91/image/Makefile b/target/linux/at91/image/Makefile
index 767255c..70ce763 100644
--- a/target/linux/at91/image/Makefile
+++ b/target/linux/at91/image/Makefile
@@ -31,7 +31,7 @@ endef
 define MkuImageDtb
 	cat $(KDIR)/zImage $(DTS_DIR)/$(2).dtb > $(KDIR)/zImage-$(1)
 	mkimage -A arm -T kernel -C none -a 0x20008000 -e 0x20008000 \
-		-n "OpenWrt ARM $(LINUX_VERSION)" \
+		-n "LEDE ARM $(LINUX_VERSION)" \
 		-d $(KDIR)/zImage-$(1) $(BIN_DIR)/$(IMG_PREFIX)-$(1)-uImage
 endef
 
diff --git a/target/linux/ath25/base-files/etc/config/system b/target/linux/ath25/base-files/etc/config/system
index 1d29ad8..c8592bb 100644
--- a/target/linux/ath25/base-files/etc/config/system
+++ b/target/linux/ath25/base-files/etc/config/system
@@ -1,5 +1,5 @@
 config system
-	option hostname OpenWrt
+	option hostname LEDE
 	option timezone UTC
 
 config timeserver ntp
diff --git a/target/linux/ath25/image/Makefile b/target/linux/ath25/image/Makefile
index 6bdb3c4..2c6a89e 100644
--- a/target/linux/ath25/image/Makefile
+++ b/target/linux/ath25/image/Makefile
@@ -24,19 +24,19 @@ define Image/Build
 	dd if=$(KDIR)/root.$(1) of=$(BIN_DIR)/$(IMG_PREFIX)-root.$(1) bs=128k conv=sync
 
 	-$(STAGING_DIR_HOST)/bin/mkfwimage \
-		-B XS2 -v XS2.ar2316.OpenWrt.$(REVISION) \
+		-B XS2 -v XS2.ar2316.LEDE.$(REVISION) \
 		-k $(BIN_DIR)/$(IMG_PREFIX)-vmlinux.lzma \
 		-r $(BIN_DIR)/$(IMG_PREFIX)-root.$(1) \
 		-o $(BIN_DIR)/$(IMG_PREFIX)-ubnt2-$(1).bin
 
 	-$(STAGING_DIR_HOST)/bin/mkfwimage \
-		-B XS5 -v XS5.ar2313.OpenWrt.$(REVISION) \
+		-B XS5 -v XS5.ar2313.LEDE.$(REVISION) \
 		-k $(BIN_DIR)/$(IMG_PREFIX)-vmlinux.lzma \
 		-r $(BIN_DIR)/$(IMG_PREFIX)-root.$(1) \
 		-o $(BIN_DIR)/$(IMG_PREFIX)-ubnt5-$(1).bin
 
 	-$(STAGING_DIR_HOST)/bin/mkfwimage \
-		-B XS2-8 -v XS2.ar2316.OpenWrt.$(REVISION) \
+		-B XS2-8 -v XS2.ar2316.LEDE.$(REVISION) \
 		-k $(BIN_DIR)/$(IMG_PREFIX)-vmlinux.lzma \
 		-r $(BIN_DIR)/$(IMG_PREFIX)-root.$(1) \
 		-o $(BIN_DIR)/$(IMG_PREFIX)-ubnt2-pico2-$(1).bin
diff --git a/target/linux/au1000/base-files/lib/upgrade/platform.sh b/target/linux/au1000/base-files/lib/upgrade/platform.sh
index 1a9d151..47315b5 100644
--- a/target/linux/au1000/base-files/lib/upgrade/platform.sh
+++ b/target/linux/au1000/base-files/lib/upgrade/platform.sh
@@ -1,5 +1,5 @@
-KERNEL_IMG="openwrt-au1000-au1500-vmlinux.bin"
-ROOTFS_IMG="openwrt-au1000-au1500-root.fs"
+KERNEL_IMG="lede-au1000-au1500-vmlinux.bin"
+ROOTFS_IMG="lede-au1000-au1500-root.fs"
 
 platform_check_image() {
 	[ "$#" -gt 1 ] && return 1
diff --git a/target/linux/brcm63xx/image/Makefile b/target/linux/brcm63xx/image/Makefile
index e00b6fb..d2aa101 100644
--- a/target/linux/brcm63xx/image/Makefile
+++ b/target/linux/brcm63xx/image/Makefile
@@ -613,10 +613,10 @@ $(eval $(call bcm63xxCfe,FAST2704N,FAST2704N,fast2704n,F@ST2704N,6318,--pad 4))
 # Sagem F@ST2704V2
 $(eval $(call bcm63xxCfe,FAST2704V2,F@ST2704V2,fast2704v2,F@ST2704V2,6328))
 # SFR Neufbox 4
-$(eval $(call bcm63xxCfe,Neufbox4,NEUFBOX4-SER,nb4-ser-r0,96358VW,6358,--rsa-signature "OpenWRT-$(REVISION)"))
-$(eval $(call bcm63xxCfe,Neufbox4,NEUFBOX4-FXC,nb4-fxc-r1,96358VW,6358,--rsa-signature "OpenWRT-$(REVISION)"))
+$(eval $(call bcm63xxCfe,Neufbox4,NEUFBOX4-SER,nb4-ser-r0,96358VW,6358,--rsa-signature "LEDE-$(REVISION)"))
+$(eval $(call bcm63xxCfe,Neufbox4,NEUFBOX4-FXC,nb4-fxc-r1,96358VW,6358,--rsa-signature "LEDE-$(REVISION)"))
 # SFR Neufbox 6
-$(eval $(call bcm63xxCfe,Neufbox6,NEUFBOX6,nb6-ser-r0,NB6-SER-r0,6362,--rsa-signature "OpenWRT-$(REVISION)"))
+$(eval $(call bcm63xxCfe,Neufbox6,NEUFBOX6,nb6-ser-r0,NB6-SER-r0,6362,--rsa-signature "LEDE-$(REVISION)"))
 # T-Com Speedport W 303V Typ B
 $(eval $(call bcm63xxCfeSpw303v,SPW303V,SPW303V,spw303v,96358-502V,6358,--pad 4))
 # T-Com Speedport W 500V
diff --git a/target/linux/brcm63xx/image/README.images-bcm63xx b/target/linux/brcm63xx/image/README.images-bcm63xx
index 91b6d01..2bdfa6b 100644
--- a/target/linux/brcm63xx/image/README.images-bcm63xx
+++ b/target/linux/brcm63xx/image/README.images-bcm63xx
@@ -1,17 +1,17 @@
-The image neede to flash onto a Broadcom 63xx-series board depends on the
+The image needed to flash onto a Broadcom 63xx-series board depends on the
 board, method you are using to flash, and, for web-based flash, on the version
 of the Broadcom code your router uses.
 
 There are two major revisions of the Broadcom code as far as imagetags are
 concerned, before 3.08 and after 3.08, however there are some variations 
 within in that, either due to vendor differences or due to changes at 
-Broadcom (it's not clear yet which is the case).  In addtion Pirelli modified
+Broadcom (it's not clear yet which is the case).  In addition Pirelli modified
 the Broadcom code, so Alice Gate models use a different imagetag than any 
 other vendor.
 
 The imagetag format for flashing via CFE is the same for almost all the 
 boards, and is the same for all images generated by the imagetag utility.
-Images flashable using cfe are labelled openwrt-<board>-<filesystem>-cfe.bin
+Images flashable using cfe are labelled lede-<board>-<filesystem>-cfe.bin
 
 The imagetags for tftp/ftp flashing is based on Broadcom 3.00-3.04 imagetags
 and is known to be correct as the source code GPL and is available for reading.
@@ -33,11 +33,11 @@ which is known to be different due to vendor (Pirelli) modifications to the
 Broadcom code.
 
 Broadcom 3.10 uses an imagetag that is believed to apply to all 3.10 and 3.12
-versions, and has been tested on the Tecom GW6200.  This version introdec changes to
-the imagetag to deal with TR69 (a remote rouer management system developed by the
+versions, and has been tested on the Tecom GW6200.  This version introduced changes to
+the imagetag to deal with TR69 (a remote router management system developed by the
 DSL forum).  There is a field for vendor-specific information, that at least in some
 cases is not optional.  It is based on the hexedit of a neufbox4 firmware image, the
-information in https://dev.openwrt.org/ticket/4987, and the hexedit of a Tecom
+information in https://dev.lede.org/ticket/4987, and the hexedit of a Tecom
 GW6200 image.
 
 Some boards share the same tag format, but require vendor-specific fields in
@@ -46,39 +46,39 @@ image reflects the router for which the image was created.
 
 router        |method       | codever |filename
 +-------------+-------------+---------+---------------------------------------
-|any          |cfe+most web |   any   |openwrt-<board>-<fs>-cfe.bin
-|AGVoIP2+WiFi |cfe          |alice3.06|openwrt-AGV2+W-cfe-<fs>-cfe.bin
-|AGVoIP2+WiFi |web          |alice3.06|openwrt-AGV2+W-cfe-<fs>-cfe.bin
-|CT536        |web          |3.02     |openwrt-CT536_CT5621-<fs>-cfe.bin
-|CT5621       |web          |3.02     |openwrt-CT536_CT5621-<fs>-cfe.bin
-|DG834GT      |web          |3.02     |openwrt-DG834GT_DG834PN-<fs>-cfe.bin
-|DG834PN      |web          |3.02     |openwrt-DG834GT_DG834PN-<fs>-cfe.bin
-|DSL-2640B    |web          |3.10     |openwrt-DSL2640B-<fs>-cfe.bin
-|DSL-2740B    |web          |3.10     |openwrt-DSL2670B-<fs>-cfe.bin
-|F5D7633      |web          |3.10     |openwrt-F5D7633-<fs>-cfe.bin
-|F@ST2404     |web          |3.0X?    |openwrt-F@ST2404-cfe-<fs>-cfe.bin
-|F@ST2404     |web          |3.1X?    |openwrt-F@ST2404-<fs>-cfe.bin
-|GW6000       |web          |3.00     |openwrt-GW6000-<fs>-cfe.bin
-|GW6200       |web          |3.10     |openwrt-GW6200-<fs>-cfe.bin
-|Neufbox4     |web          |3.12     |openwrt-NEUFBOX4-<fs>-cfe.bin
-|TD8810A      |web          |3.06     |openwrt-TD8810-<fs>-cfe.bin
-|TD8810B      |web          |3.06     |openwrt-TD8810-<fs>-cfe.bin
-|TD8811A      |web          |3.06     |openwrt-TD8811-<fs>-cfe.bin
-|TD8811B      |web          |3.06     |openwrt-TD881-<fs>-cfe.bin
-|TD8900GB     |web          |3.06     |openwrt-TD8900DB<fs>-cfe.bin
-|USR9108      |web          |3.0X?    |openwrt-USR9108-<fs>-cfe.bin
-|V2091_BTR    |web          |2.21     |openwrt-V2091_BTR-<fs>-cfe.bin
-|V2091_ROI    |web          |2.21     |openwrt-V2091-<fs>-cfe.bin
-|V2091_WB     |web          |2.21     |openwrt-V2091-<fs>-cfe.bin
-|V210_BTR     |web          |2.21     |openwrt-V210_BTR-<fs>-cfe.bin
-|V210_ROI     |web          |2.21     |openwrt-V210-ROI_WB<fs>-cfe.bin
-|V210_WB      |web          |2.21     |openwrt-V210-ROI_WB<fs>-cfe.bin
-|V2110        |web          |2.21     |openwrt-V2110-<fs>-cfe.bin
-|V2110_AA     |web          |2.21     |openwrt-V2110-<fs>-cfe.bin
-|V2110_ROI    |web          |2.21     |openwrt-V2110-<fs>-cfe.bin
-|V2500V       |web          |2.21     |openwrt-V2500V<fs>-cfe.bin
-|V2500V_AA    |web          |2.21     |openwrt-V2500V-<fs>-cfe.bin
-|V2500V_SIP_CLUB |web       |2.21     |openwrt-V2500V-<fs>-cfe.bin
+|any          |cfe+most web |   any   |lede-<board>-<fs>-cfe.bin
+|AGVoIP2+WiFi |cfe          |alice3.06|lede-AGV2+W-cfe-<fs>-cfe.bin
+|AGVoIP2+WiFi |web          |alice3.06|lede-AGV2+W-cfe-<fs>-cfe.bin
+|CT536        |web          |3.02     |lede-CT536_CT5621-<fs>-cfe.bin
+|CT5621       |web          |3.02     |lede-CT536_CT5621-<fs>-cfe.bin
+|DG834GT      |web          |3.02     |lede-DG834GT_DG834PN-<fs>-cfe.bin
+|DG834PN      |web          |3.02     |lede-DG834GT_DG834PN-<fs>-cfe.bin
+|DSL-2640B    |web          |3.10     |lede-DSL2640B-<fs>-cfe.bin
+|DSL-2740B    |web          |3.10     |lede-DSL2670B-<fs>-cfe.bin
+|F5D7633      |web          |3.10     |lede-F5D7633-<fs>-cfe.bin
+|F@ST2404     |web          |3.0X?    |lede-F@ST2404-cfe-<fs>-cfe.bin
+|F@ST2404     |web          |3.1X?    |lede-F@ST2404-<fs>-cfe.bin
+|GW6000       |web          |3.00     |lede-GW6000-<fs>-cfe.bin
+|GW6200       |web          |3.10     |lede-GW6200-<fs>-cfe.bin
+|Neufbox4     |web          |3.12     |lede-NEUFBOX4-<fs>-cfe.bin
+|TD8810A      |web          |3.06     |lede-TD8810-<fs>-cfe.bin
+|TD8810B      |web          |3.06     |lede-TD8810-<fs>-cfe.bin
+|TD8811A      |web          |3.06     |lede-TD8811-<fs>-cfe.bin
+|TD8811B      |web          |3.06     |lede-TD881-<fs>-cfe.bin
+|TD8900GB     |web          |3.06     |lede-TD8900DB<fs>-cfe.bin
+|USR9108      |web          |3.0X?    |lede-USR9108-<fs>-cfe.bin
+|V2091_BTR    |web          |2.21     |lede-V2091_BTR-<fs>-cfe.bin
+|V2091_ROI    |web          |2.21     |lede-V2091-<fs>-cfe.bin
+|V2091_WB     |web          |2.21     |lede-V2091-<fs>-cfe.bin
+|V210_BTR     |web          |2.21     |lede-V210_BTR-<fs>-cfe.bin
+|V210_ROI     |web          |2.21     |lede-V210-ROI_WB<fs>-cfe.bin
+|V210_WB      |web          |2.21     |lede-V210-ROI_WB<fs>-cfe.bin
+|V2110        |web          |2.21     |lede-V2110-<fs>-cfe.bin
+|V2110_AA     |web          |2.21     |lede-V2110-<fs>-cfe.bin
+|V2110_ROI    |web          |2.21     |lede-V2110-<fs>-cfe.bin
+|V2500V       |web          |2.21     |lede-V2500V<fs>-cfe.bin
+|V2500V_AA    |web          |2.21     |lede-V2500V-<fs>-cfe.bin
+|V2500V_SIP_CLUB |web       |2.21     |lede-V2500V-<fs>-cfe.bin
 
 Old imagetag routers
 --------------------
diff --git a/target/linux/gemini/image/Makefile b/target/linux/gemini/image/Makefile
index 1c51b62..9e4e455 100644
--- a/target/linux/gemini/image/Makefile
+++ b/target/linux/gemini/image/Makefile
@@ -54,14 +54,14 @@ define Image/Build
 	$(call Image/Build/$(1),$(1))
 	-$(STAGING_DIR_HOST)/bin/mkfwimage2 \
 		-m GEOS -f 0x30000000 -z \
-		-v WILI-S.WILIBOARD.v5.00.SL3512.OpenWrt.00000.000000.000000 \
+		-v WILI-S.WILIBOARD.v5.00.SL3512.LEDE.00000.000000.000000 \
 		-o $(BIN_DIR)/$(IMG_PREFIX)-wbd111-$(1).bin \
 		-p Kernel:0x020000:0x100000:0:0:$(BIN_DIR)/$(IMG_PREFIX)-wbd111-zImage \
 		-p Ramdisk:0x120000:0x500000:0:0:$(BIN_DIR)/$(IMG_PREFIX)-$(1).img
 
 	-$(STAGING_DIR_HOST)/bin/mkfwimage2 \
 		-m GEOS -f 0x30000000 -z \
-		-v WILI-S.WBD222.v5.00.SL3512.OpenWrt.00000.000000.000000 \
+		-v WILI-S.WBD222.v5.00.SL3512.LEDE.00000.000000.000000 \
 		-o $(BIN_DIR)/$(IMG_PREFIX)-wbd222-$(1).bin \
 		-p Kernel:0x020000:0x100000:0:0:$(BIN_DIR)/$(IMG_PREFIX)-wbd222-zImage \
 		-p Ramdisk:0x120000:0x500000:0:0:$(BIN_DIR)/$(IMG_PREFIX)-$(1).img
diff --git a/target/linux/generic/patches-3.18/230-lede_lzma_options.patch b/target/linux/generic/patches-3.18/230-lede_lzma_options.patch
new file mode 100644
index 0000000..2915c73
--- /dev/null
+++ b/target/linux/generic/patches-3.18/230-lede_lzma_options.patch
@@ -0,0 +1,58 @@
+--- a/scripts/Makefile.lib
++++ b/scripts/Makefile.lib
+@@ -325,7 +325,7 @@ cmd_bzip2 = (cat $(filter-out FORCE,$^)
+ 
+ quiet_cmd_lzma = LZMA    $@
+ cmd_lzma = (cat $(filter-out FORCE,$^) | \
+-	lzma -9 && $(call size_append, $(filter-out FORCE,$^))) > $@ || \
++	lzma e -d20 -lc1 -lp2 -pb2 -eos -si -so && $(call size_append, $(filter-out FORCE,$^))) > $@ || \
+ 	(rm -f $@ ; false)
+ 
+ quiet_cmd_lzo = LZO     $@
+--- a/scripts/gen_initramfs_list.sh
++++ b/scripts/gen_initramfs_list.sh
+@@ -226,7 +226,7 @@ cpio_list=
+ output="/dev/stdout"
+ output_file=""
+ is_cpio_compressed=
+-compr="gzip -n -9 -f"
++compr="gzip -n -9 -f -"
+ 
+ arg="$1"
+ case "$arg" in
+@@ -242,13 +242,13 @@ case "$arg" in
+ 		output=${cpio_list}
+ 		echo "$output_file" | grep -q "\.gz$" \
+                 && [ -x "`which gzip 2> /dev/null`" ] \
+-                && compr="gzip -n -9 -f"
++                && compr="gzip -n -9 -f -"
+ 		echo "$output_file" | grep -q "\.bz2$" \
+                 && [ -x "`which bzip2 2> /dev/null`" ] \
+-                && compr="bzip2 -9 -f"
++                && compr="bzip2 -9 -f -"
+ 		echo "$output_file" | grep -q "\.lzma$" \
+                 && [ -x "`which lzma 2> /dev/null`" ] \
+-                && compr="lzma -9 -f"
++                && compr="lzma e -d20 -lc1 -lp2 -pb2 -eos -si -so"
+ 		echo "$output_file" | grep -q "\.xz$" \
+                 && [ -x "`which xz 2> /dev/null`" ] \
+                 && compr="xz --check=crc32 --lzma2=dict=1MiB"
+@@ -315,7 +315,7 @@ if [ ! -z ${output_file} ]; then
+ 	if [ "${is_cpio_compressed}" = "compressed" ]; then
+ 		cat ${cpio_tfile} > ${output_file}
+ 	else
+-		(cat ${cpio_tfile} | ${compr}  - > ${output_file}) \
++		(cat ${cpio_tfile} | ${compr} > ${output_file}) \
+ 		|| (rm -f ${output_file} ; false)
+ 	fi
+ 	[ -z ${cpio_file} ] && rm ${cpio_tfile}
+--- a/lib/decompress.c
++++ b/lib/decompress.c
+@@ -48,6 +48,7 @@ static const struct compress_format comp
+ 	{ {037, 0236}, "gzip", gunzip },
+ 	{ {0x42, 0x5a}, "bzip2", bunzip2 },
+ 	{ {0x5d, 0x00}, "lzma", unlzma },
++	{ {0x6d, 0x00}, "lzma-cshorewrt", unlzma },
+ 	{ {0xfd, 0x37}, "xz", unxz },
+ 	{ {0x89, 0x4c}, "lzo", unlzo },
+ 	{ {0x02, 0x21}, "lz4", unlz4 },
diff --git a/target/linux/generic/patches-3.18/230-openwrt_lzma_options.patch b/target/linux/generic/patches-3.18/230-openwrt_lzma_options.patch
deleted file mode 100644
index e59fdcd..0000000
--- a/target/linux/generic/patches-3.18/230-openwrt_lzma_options.patch
+++ /dev/null
@@ -1,58 +0,0 @@
---- a/scripts/Makefile.lib
-+++ b/scripts/Makefile.lib
-@@ -325,7 +325,7 @@ cmd_bzip2 = (cat $(filter-out FORCE,$^)
- 
- quiet_cmd_lzma = LZMA    $@
- cmd_lzma = (cat $(filter-out FORCE,$^) | \
--	lzma -9 && $(call size_append, $(filter-out FORCE,$^))) > $@ || \
-+	lzma e -d20 -lc1 -lp2 -pb2 -eos -si -so && $(call size_append, $(filter-out FORCE,$^))) > $@ || \
- 	(rm -f $@ ; false)
- 
- quiet_cmd_lzo = LZO     $@
---- a/scripts/gen_initramfs_list.sh
-+++ b/scripts/gen_initramfs_list.sh
-@@ -226,7 +226,7 @@ cpio_list=
- output="/dev/stdout"
- output_file=""
- is_cpio_compressed=
--compr="gzip -n -9 -f"
-+compr="gzip -n -9 -f -"
- 
- arg="$1"
- case "$arg" in
-@@ -242,13 +242,13 @@ case "$arg" in
- 		output=${cpio_list}
- 		echo "$output_file" | grep -q "\.gz$" \
-                 && [ -x "`which gzip 2> /dev/null`" ] \
--                && compr="gzip -n -9 -f"
-+                && compr="gzip -n -9 -f -"
- 		echo "$output_file" | grep -q "\.bz2$" \
-                 && [ -x "`which bzip2 2> /dev/null`" ] \
--                && compr="bzip2 -9 -f"
-+                && compr="bzip2 -9 -f -"
- 		echo "$output_file" | grep -q "\.lzma$" \
-                 && [ -x "`which lzma 2> /dev/null`" ] \
--                && compr="lzma -9 -f"
-+                && compr="lzma e -d20 -lc1 -lp2 -pb2 -eos -si -so"
- 		echo "$output_file" | grep -q "\.xz$" \
-                 && [ -x "`which xz 2> /dev/null`" ] \
-                 && compr="xz --check=crc32 --lzma2=dict=1MiB"
-@@ -315,7 +315,7 @@ if [ ! -z ${output_file} ]; then
- 	if [ "${is_cpio_compressed}" = "compressed" ]; then
- 		cat ${cpio_tfile} > ${output_file}
- 	else
--		(cat ${cpio_tfile} | ${compr}  - > ${output_file}) \
-+		(cat ${cpio_tfile} | ${compr} > ${output_file}) \
- 		|| (rm -f ${output_file} ; false)
- 	fi
- 	[ -z ${cpio_file} ] && rm ${cpio_tfile}
---- a/lib/decompress.c
-+++ b/lib/decompress.c
-@@ -48,6 +48,7 @@ static const struct compress_format comp
- 	{ {037, 0236}, "gzip", gunzip },
- 	{ {0x42, 0x5a}, "bzip2", bunzip2 },
- 	{ {0x5d, 0x00}, "lzma", unlzma },
-+	{ {0x6d, 0x00}, "lzma-openwrt", unlzma },
- 	{ {0xfd, 0x37}, "xz", unxz },
- 	{ {0x89, 0x4c}, "lzo", unlzo },
- 	{ {0x02, 0x21}, "lz4", unlz4 },
diff --git a/target/linux/generic/patches-4.1/230-lede_lzma_options.patch b/target/linux/generic/patches-4.1/230-lede_lzma_options.patch
new file mode 100644
index 0000000..26dd859
--- /dev/null
+++ b/target/linux/generic/patches-4.1/230-lede_lzma_options.patch
@@ -0,0 +1,58 @@
+--- a/scripts/Makefile.lib
++++ b/scripts/Makefile.lib
+@@ -324,7 +324,7 @@ cmd_bzip2 = (cat $(filter-out FORCE,$^)
+ 
+ quiet_cmd_lzma = LZMA    $@
+ cmd_lzma = (cat $(filter-out FORCE,$^) | \
+-	lzma -9 && $(call size_append, $(filter-out FORCE,$^))) > $@ || \
++	lzma e -d20 -lc1 -lp2 -pb2 -eos -si -so && $(call size_append, $(filter-out FORCE,$^))) > $@ || \
+ 	(rm -f $@ ; false)
+ 
+ quiet_cmd_lzo = LZO     $@
+--- a/scripts/gen_initramfs_list.sh
++++ b/scripts/gen_initramfs_list.sh
+@@ -226,7 +226,7 @@ cpio_list=
+ output="/dev/stdout"
+ output_file=""
+ is_cpio_compressed=
+-compr="gzip -n -9 -f"
++compr="gzip -n -9 -f -"
+ 
+ arg="$1"
+ case "$arg" in
+@@ -242,13 +242,13 @@ case "$arg" in
+ 		output=${cpio_list}
+ 		echo "$output_file" | grep -q "\.gz$" \
+                 && [ -x "`which gzip 2> /dev/null`" ] \
+-                && compr="gzip -n -9 -f"
++                && compr="gzip -n -9 -f -"
+ 		echo "$output_file" | grep -q "\.bz2$" \
+                 && [ -x "`which bzip2 2> /dev/null`" ] \
+-                && compr="bzip2 -9 -f"
++                && compr="bzip2 -9 -f -"
+ 		echo "$output_file" | grep -q "\.lzma$" \
+                 && [ -x "`which lzma 2> /dev/null`" ] \
+-                && compr="lzma -9 -f"
++                && compr="lzma e -d20 -lc1 -lp2 -pb2 -eos -si -so"
+ 		echo "$output_file" | grep -q "\.xz$" \
+                 && [ -x "`which xz 2> /dev/null`" ] \
+                 && compr="xz --check=crc32 --lzma2=dict=1MiB"
+@@ -315,7 +315,7 @@ if [ ! -z ${output_file} ]; then
+ 	if [ "${is_cpio_compressed}" = "compressed" ]; then
+ 		cat ${cpio_tfile} > ${output_file}
+ 	else
+-		(cat ${cpio_tfile} | ${compr}  - > ${output_file}) \
++		(cat ${cpio_tfile} | ${compr} > ${output_file}) \
+ 		|| (rm -f ${output_file} ; false)
+ 	fi
+ 	[ -z ${cpio_file} ] && rm ${cpio_tfile}
+--- a/lib/decompress.c
++++ b/lib/decompress.c
+@@ -48,6 +48,7 @@ static const struct compress_format comp
+ 	{ {0x1f, 0x9e}, "gzip", gunzip },
+ 	{ {0x42, 0x5a}, "bzip2", bunzip2 },
+ 	{ {0x5d, 0x00}, "lzma", unlzma },
++	{ {0x6d, 0x00}, "lzma-cshorewrt", unlzma },
+ 	{ {0xfd, 0x37}, "xz", unxz },
+ 	{ {0x89, 0x4c}, "lzo", unlzo },
+ 	{ {0x02, 0x21}, "lz4", unlz4 },
diff --git a/target/linux/generic/patches-4.1/230-openwrt_lzma_options.patch b/target/linux/generic/patches-4.1/230-openwrt_lzma_options.patch
deleted file mode 100644
index d5bbb19..0000000
--- a/target/linux/generic/patches-4.1/230-openwrt_lzma_options.patch
+++ /dev/null
@@ -1,58 +0,0 @@
---- a/scripts/Makefile.lib
-+++ b/scripts/Makefile.lib
-@@ -324,7 +324,7 @@ cmd_bzip2 = (cat $(filter-out FORCE,$^)
- 
- quiet_cmd_lzma = LZMA    $@
- cmd_lzma = (cat $(filter-out FORCE,$^) | \
--	lzma -9 && $(call size_append, $(filter-out FORCE,$^))) > $@ || \
-+	lzma e -d20 -lc1 -lp2 -pb2 -eos -si -so && $(call size_append, $(filter-out FORCE,$^))) > $@ || \
- 	(rm -f $@ ; false)
- 
- quiet_cmd_lzo = LZO     $@
---- a/scripts/gen_initramfs_list.sh
-+++ b/scripts/gen_initramfs_list.sh
-@@ -226,7 +226,7 @@ cpio_list=
- output="/dev/stdout"
- output_file=""
- is_cpio_compressed=
--compr="gzip -n -9 -f"
-+compr="gzip -n -9 -f -"
- 
- arg="$1"
- case "$arg" in
-@@ -242,13 +242,13 @@ case "$arg" in
- 		output=${cpio_list}
- 		echo "$output_file" | grep -q "\.gz$" \
-                 && [ -x "`which gzip 2> /dev/null`" ] \
--                && compr="gzip -n -9 -f"
-+                && compr="gzip -n -9 -f -"
- 		echo "$output_file" | grep -q "\.bz2$" \
-                 && [ -x "`which bzip2 2> /dev/null`" ] \
--                && compr="bzip2 -9 -f"
-+                && compr="bzip2 -9 -f -"
- 		echo "$output_file" | grep -q "\.lzma$" \
-                 && [ -x "`which lzma 2> /dev/null`" ] \
--                && compr="lzma -9 -f"
-+                && compr="lzma e -d20 -lc1 -lp2 -pb2 -eos -si -so"
- 		echo "$output_file" | grep -q "\.xz$" \
-                 && [ -x "`which xz 2> /dev/null`" ] \
-                 && compr="xz --check=crc32 --lzma2=dict=1MiB"
-@@ -315,7 +315,7 @@ if [ ! -z ${output_file} ]; then
- 	if [ "${is_cpio_compressed}" = "compressed" ]; then
- 		cat ${cpio_tfile} > ${output_file}
- 	else
--		(cat ${cpio_tfile} | ${compr}  - > ${output_file}) \
-+		(cat ${cpio_tfile} | ${compr} > ${output_file}) \
- 		|| (rm -f ${output_file} ; false)
- 	fi
- 	[ -z ${cpio_file} ] && rm ${cpio_tfile}
---- a/lib/decompress.c
-+++ b/lib/decompress.c
-@@ -48,6 +48,7 @@ static const struct compress_format comp
- 	{ {0x1f, 0x9e}, "gzip", gunzip },
- 	{ {0x42, 0x5a}, "bzip2", bunzip2 },
- 	{ {0x5d, 0x00}, "lzma", unlzma },
-+	{ {0x6d, 0x00}, "lzma-openwrt", unlzma },
- 	{ {0xfd, 0x37}, "xz", unxz },
- 	{ {0x89, 0x4c}, "lzo", unlzo },
- 	{ {0x02, 0x21}, "lz4", unlz4 },
diff --git a/target/linux/generic/patches-4.4/230-lede_lzma_options.patch b/target/linux/generic/patches-4.4/230-lede_lzma_options.patch
new file mode 100644
index 0000000..085cbfd
--- /dev/null
+++ b/target/linux/generic/patches-4.4/230-lede_lzma_options.patch
@@ -0,0 +1,58 @@
+--- a/scripts/Makefile.lib
++++ b/scripts/Makefile.lib
+@@ -324,7 +324,7 @@ cmd_bzip2 = (cat $(filter-out FORCE,$^)
+ 
+ quiet_cmd_lzma = LZMA    $@
+ cmd_lzma = (cat $(filter-out FORCE,$^) | \
+-	lzma -9 && $(call size_append, $(filter-out FORCE,$^))) > $@ || \
++	lzma e -d20 -lc1 -lp2 -pb2 -eos -si -so && $(call size_append, $(filter-out FORCE,$^))) > $@ || \
+ 	(rm -f $@ ; false)
+ 
+ quiet_cmd_lzo = LZO     $@
+--- a/scripts/gen_initramfs_list.sh
++++ b/scripts/gen_initramfs_list.sh
+@@ -226,7 +226,7 @@ cpio_list=
+ output="/dev/stdout"
+ output_file=""
+ is_cpio_compressed=
+-compr="gzip -n -9 -f"
++compr="gzip -n -9 -f -"
+ 
+ arg="$1"
+ case "$arg" in
+@@ -242,13 +242,13 @@ case "$arg" in
+ 		output=${cpio_list}
+ 		echo "$output_file" | grep -q "\.gz$" \
+                 && [ -x "`which gzip 2> /dev/null`" ] \
+-                && compr="gzip -n -9 -f"
++                && compr="gzip -n -9 -f -"
+ 		echo "$output_file" | grep -q "\.bz2$" \
+                 && [ -x "`which bzip2 2> /dev/null`" ] \
+-                && compr="bzip2 -9 -f"
++                && compr="bzip2 -9 -f -"
+ 		echo "$output_file" | grep -q "\.lzma$" \
+                 && [ -x "`which lzma 2> /dev/null`" ] \
+-                && compr="lzma -9 -f"
++                && compr="lzma e -d20 -lc1 -lp2 -pb2 -eos -si -so"
+ 		echo "$output_file" | grep -q "\.xz$" \
+                 && [ -x "`which xz 2> /dev/null`" ] \
+                 && compr="xz --check=crc32 --lzma2=dict=1MiB"
+@@ -315,7 +315,7 @@ if [ ! -z ${output_file} ]; then
+ 	if [ "${is_cpio_compressed}" = "compressed" ]; then
+ 		cat ${cpio_tfile} > ${output_file}
+ 	else
+-		(cat ${cpio_tfile} | ${compr}  - > ${output_file}) \
++		(cat ${cpio_tfile} | ${compr} > ${output_file}) \
+ 		|| (rm -f ${output_file} ; false)
+ 	fi
+ 	[ -z ${cpio_file} ] && rm ${cpio_tfile}
+--- a/lib/decompress.c
++++ b/lib/decompress.c
+@@ -48,6 +48,7 @@ static const struct compress_format comp
+ 	{ {0x1f, 0x9e}, "gzip", gunzip },
+ 	{ {0x42, 0x5a}, "bzip2", bunzip2 },
+ 	{ {0x5d, 0x00}, "lzma", unlzma },
++	{ {0x6d, 0x00}, "lzma-lede", unlzma },
+ 	{ {0xfd, 0x37}, "xz", unxz },
+ 	{ {0x89, 0x4c}, "lzo", unlzo },
+ 	{ {0x02, 0x21}, "lz4", unlz4 },
diff --git a/target/linux/generic/patches-4.4/230-openwrt_lzma_options.patch b/target/linux/generic/patches-4.4/230-openwrt_lzma_options.patch
deleted file mode 100644
index d5bbb19..0000000
--- a/target/linux/generic/patches-4.4/230-openwrt_lzma_options.patch
+++ /dev/null
@@ -1,58 +0,0 @@
---- a/scripts/Makefile.lib
-+++ b/scripts/Makefile.lib
-@@ -324,7 +324,7 @@ cmd_bzip2 = (cat $(filter-out FORCE,$^)
- 
- quiet_cmd_lzma = LZMA    $@
- cmd_lzma = (cat $(filter-out FORCE,$^) | \
--	lzma -9 && $(call size_append, $(filter-out FORCE,$^))) > $@ || \
-+	lzma e -d20 -lc1 -lp2 -pb2 -eos -si -so && $(call size_append, $(filter-out FORCE,$^))) > $@ || \
- 	(rm -f $@ ; false)
- 
- quiet_cmd_lzo = LZO     $@
---- a/scripts/gen_initramfs_list.sh
-+++ b/scripts/gen_initramfs_list.sh
-@@ -226,7 +226,7 @@ cpio_list=
- output="/dev/stdout"
- output_file=""
- is_cpio_compressed=
--compr="gzip -n -9 -f"
-+compr="gzip -n -9 -f -"
- 
- arg="$1"
- case "$arg" in
-@@ -242,13 +242,13 @@ case "$arg" in
- 		output=${cpio_list}
- 		echo "$output_file" | grep -q "\.gz$" \
-                 && [ -x "`which gzip 2> /dev/null`" ] \
--                && compr="gzip -n -9 -f"
-+                && compr="gzip -n -9 -f -"
- 		echo "$output_file" | grep -q "\.bz2$" \
-                 && [ -x "`which bzip2 2> /dev/null`" ] \
--                && compr="bzip2 -9 -f"
-+                && compr="bzip2 -9 -f -"
- 		echo "$output_file" | grep -q "\.lzma$" \
-                 && [ -x "`which lzma 2> /dev/null`" ] \
--                && compr="lzma -9 -f"
-+                && compr="lzma e -d20 -lc1 -lp2 -pb2 -eos -si -so"
- 		echo "$output_file" | grep -q "\.xz$" \
-                 && [ -x "`which xz 2> /dev/null`" ] \
-                 && compr="xz --check=crc32 --lzma2=dict=1MiB"
-@@ -315,7 +315,7 @@ if [ ! -z ${output_file} ]; then
- 	if [ "${is_cpio_compressed}" = "compressed" ]; then
- 		cat ${cpio_tfile} > ${output_file}
- 	else
--		(cat ${cpio_tfile} | ${compr}  - > ${output_file}) \
-+		(cat ${cpio_tfile} | ${compr} > ${output_file}) \
- 		|| (rm -f ${output_file} ; false)
- 	fi
- 	[ -z ${cpio_file} ] && rm ${cpio_tfile}
---- a/lib/decompress.c
-+++ b/lib/decompress.c
-@@ -48,6 +48,7 @@ static const struct compress_format comp
- 	{ {0x1f, 0x9e}, "gzip", gunzip },
- 	{ {0x42, 0x5a}, "bzip2", bunzip2 },
- 	{ {0x5d, 0x00}, "lzma", unlzma },
-+	{ {0x6d, 0x00}, "lzma-openwrt", unlzma },
- 	{ {0xfd, 0x37}, "xz", unxz },
- 	{ {0x89, 0x4c}, "lzo", unlzo },
- 	{ {0x02, 0x21}, "lz4", unlz4 },
diff --git a/target/linux/ipq806x/image/Makefile b/target/linux/ipq806x/image/Makefile
index ff8b2c7..289797e 100644
--- a/target/linux/ipq806x/image/Makefile
+++ b/target/linux/ipq806x/image/Makefile
@@ -12,7 +12,7 @@ define Image/Prepare
 	$(CP) $(LINUX_DIR)/vmlinux $(KDIR)/$(IMG_PREFIX)-vmlinux.elf
 	mkimage -A arm -O linux -T filesystem -C none \
 		-a $(KERNEL_LOADADDR) -e $(KERNEL_LOADADDR) \
-		-n 'ARM OpenWrt fakeroot' \
+		-n 'ARM LEDE fakeroot' \
 		-s $(KDIR_TMP)/root.dummy-uImage.tmp
 	echo -ne '\xff' > $(KDIR_TMP)/root.dummy
 	cat $(KDIR_TMP)/root.dummy $(KDIR_TMP)/root.dummy-uImage.tmp > $(KDIR)/root.dummy
diff --git a/target/linux/lantiq/image/Makefile b/target/linux/lantiq/image/Makefile
index 67fdff6..f7ca01b 100644
--- a/target/linux/lantiq/image/Makefile
+++ b/target/linux/lantiq/image/Makefile
@@ -41,7 +41,7 @@ endef
 
 define MkImageLzma
 	mkimage -A mips -O linux -T kernel -a 0x80002000 -C lzma \
-		-e 0x80002000 -n 'MIPS OpenWrt Linux-$(LINUX_VERSION)' \
+		-e 0x80002000 -n 'MIPS LEDE Linux-$(LINUX_VERSION)' \
 		-d $(KDIR)/vmlinux$(2)-$(1).lzma $(KDIR)/uImage-$(1)$(2)
 endef
 
diff --git a/target/linux/malta/README b/target/linux/malta/README
index 22bdff5..35cc76f 100644
--- a/target/linux/malta/README
+++ b/target/linux/malta/README
@@ -1,13 +1,13 @@
 This Malta target is intended to be used with the Qemu emulator. It can be used
-to prototype an OpenWrt firmware for MIPS processors. One could also use it to
+to prototype an LEDE firmware for MIPS processors. One could also use it to
 troubleshoot MIPS applications without access to real hardware.
 
-To use the images built by OpenWrt with qemu, use the following commands:
+To use the images built by LEDE with qemu, use the following commands:
 
 For the little-endian image:
-qemu-system-mipsel -kernel bin/malta/openwrt-malta-le-vmlinux-initramfs.elf -nographic -m 256
+qemu-system-mipsel -kernel bin/malta/lede-malta-le-vmlinux-initramfs.elf -nographic -m 256
 
 For the big-endian image:
-qemu-system-mips -kernel bin/malta/openwrt-malta-be-vmlinux-initramfs.elf -nographic -m 256
+qemu-system-mips -kernel bin/malta/lede-malta-be-vmlinux-initramfs.elf -nographic -m 256
 
 and enjoy the system bootin.
diff --git a/target/linux/malta/image/Makefile b/target/linux/malta/image/Makefile
index 180e045..8f271c0 100644
--- a/target/linux/malta/image/Makefile
+++ b/target/linux/malta/image/Makefile
@@ -21,7 +21,7 @@ endef
 
 define MkuImage
 	mkimage -A mips -O linux -T kernel -a 0x80100000 -C $(1) $(2) \
-		-e $(call get_kernel_entry,$(KDIR)/vmlinux.debug) -n 'MIPS OpenWrt Linux-$(LINUX_VERSION)' \
+		-e $(call get_kernel_entry,$(KDIR)/vmlinux.debug) -n 'MIPS LEDE Linux-$(LINUX_VERSION)' \
 		-d $(3) $(4)
 endef
 
diff --git a/target/linux/mediatek/config-4.4 b/target/linux/mediatek/config-4.4
index e69a74f..d13a2ca 100644
--- a/target/linux/mediatek/config-4.4
+++ b/target/linux/mediatek/config-4.4
@@ -234,7 +234,7 @@ CONFIG_I2C_CHARDEV=y
 CONFIG_I2C_MT65XX=y
 CONFIG_INITRAMFS_ROOT_GID=1000
 CONFIG_INITRAMFS_ROOT_UID=1000
-CONFIG_INITRAMFS_SOURCE="/openwrt/trunk/build_dir/target-arm_cortex-a7_musl-1.1.14_eabi/root-mediatek /openwrt/trunk/target/linux/generic/image/initramfs-base-files.txt"
+CONFIG_INITRAMFS_SOURCE="/lede/trunk/build_dir/target-arm_cortex-a7_musl-1.1.14_eabi/root-mediatek /cshorwrt/trunk/target/linux/generic/image/initramfs-base-files.txt"
 CONFIG_IOMMU_HELPER=y
 # CONFIG_IOMMU_IO_PGTABLE_LPAE is not set
 CONFIG_IOMMU_SUPPORT=y
diff --git a/target/linux/mxs/image/Makefile b/target/linux/mxs/image/Makefile
index 94fed82..15e96e8 100644
--- a/target/linux/mxs/image/Makefile
+++ b/target/linux/mxs/image/Makefile
@@ -18,7 +18,7 @@ FAT32_BLOCKS=$(shell echo $$(($(CONFIG_TARGET_BOOTFS_PARTSIZE)*1024*1024/$(FAT32
 define Image/BuildKernel
 	mkimage -A arm -O linux -T kernel -C none \
 		-a 0x40008000 -e 0x40008000 \
-		-n 'ARM OpenWrt Linux-$(LINUX_VERSION)' \
+		-n 'ARM LEDE Linux-$(LINUX_VERSION)' \
 		-d $(KDIR)/zImage $(KDIR)/uImage
 	cp $(KDIR)/uImage $(BIN_DIR)/$(IMG_PREFIX)-uImage
 endef
diff --git a/target/linux/orion/image/generic.mk b/target/linux/orion/image/generic.mk
index 905997d..f464c5d 100644
--- a/target/linux/orion/image/generic.mk
+++ b/target/linux/orion/image/generic.mk
@@ -85,7 +85,7 @@ define Image/BuildKernel/ARM/uImage
 	-C none -a 0x00008000 -e 0x00008000 -n 'Linux-$(LINUX_VERSION)' \
 	-d '$(KDIR)/$(1)-zImage$(2)' '$(KDIR)/$(1)-uImage$(2)'
  ifeq ($(2),-initramfs) # only copy uImage for ramdisk build
-	cp '$(KDIR)/$(1)-uImage-initramfs' '$(BIN_DIR)/openwrt-$(1)-uImage-initramfs'
+	cp '$(KDIR)/$(1)-uImage-initramfs' '$(BIN_DIR)/lede-$(1)-uImage-initramfs'
  endif
 endef
 
@@ -162,13 +162,13 @@ define Image/Build/Default/sysupgrade
 	( \
 		dd if='$(KDIR)/$(2)-uImage$(4)' bs=$(3)k conv=sync; \
 		dd if='$(KDIR)/root.$(1)'; \
-	) > '$(BIN_DIR)/openwrt-$(2)-$(1)-sysupgrade.img'
+	) > '$(BIN_DIR)/lede-$(2)-$(1)-sysupgrade.img'
 endef
 
 define Image/Build/Default/factory
  # parameters: 1 = rootfs type, 2 = machine name, 3 = header
 	# $(BOARD) $(1) factory upgrade image for $(2)
-	'$(STAGING_DIR_HOST)/bin/add_header' $(3) '$(BIN_DIR)/openwrt-$(2)-$(1)-sysupgrade.img' '$(BIN_DIR)/openwrt-$(2)-$(1)-factory.img'
+	'$(STAGING_DIR_HOST)/bin/add_header' $(3) '$(BIN_DIR)/lede-$(2)-$(1)-sysupgrade.img' '$(BIN_DIR)/lede-$(2)-$(1)-factory.img'
 endef
 
 ##
@@ -198,7 +198,7 @@ define Image/Build/Linksys/wrt350nv2-builder
 	rm -rf '$(TMP_DIR)/$(2)_factory'
 	mkdir '$(TMP_DIR)/$(2)_factory'
  # create parameter file
-	echo ':image 0 $(BIN_DIR)/openwrt-$(2)-$(1)-sysupgrade.img' > '$(TMP_DIR)/$(2)_factory/$(2).par'
+	echo ':image 0 $(BIN_DIR)/lede-$(2)-$(1)-sysupgrade.img' > '$(TMP_DIR)/$(2)_factory/$(2).par'
 	[ ! -f '$(STAGING_DIR_HOST)/share/wrt350nv2-builder/u-boot.bin' ] || ( \
 		echo ':u-boot 0 $(STAGING_DIR_HOST)/share/wrt350nv2-builder/u-boot.bin' >> '$(TMP_DIR)/$(2)_factory/$(2).par'; \
 	)
@@ -209,13 +209,13 @@ define Image/Build/Linksys/wrt350nv2-builder
 		'$(STAGING_DIR_HOST)/bin/wrt350nv2-builder' -b '$(TMP_DIR)/$(2)_factory/$(2).par'; \
 	)
  # copy bin file as recovery image
-	$(CP) '$(TMP_DIR)/$(2)_factory/wrt350n.bin' '$(BIN_DIR)/openwrt-$(2)-$(1)-recovery.bin'
+	$(CP) '$(TMP_DIR)/$(2)_factory/wrt350n.bin' '$(BIN_DIR)/lede-$(2)-$(1)-recovery.bin'
  # create factory image for stock firmware update mechanism
 	( \
 		cd '$(TMP_DIR)/$(2)_factory'; \
 		zip 'wrt350n.zip' 'wrt350n.bin'; \
 	)
-	'$(STAGING_DIR_HOST)/bin/wrt350nv2-builder' -z '$(TMP_DIR)/$(2)_factory/wrt350n.zip' '$(BIN_DIR)/openwrt-$(2)-$(1)-factory.img'
+	'$(STAGING_DIR_HOST)/bin/wrt350nv2-builder' -z '$(TMP_DIR)/$(2)_factory/wrt350n.zip' '$(BIN_DIR)/lede-$(2)-$(1)-factory.img'
 	rm -rf '$(TMP_DIR)/$(2)_factory'
 endef
 
diff --git a/target/linux/orion/image/harddisk.mk b/target/linux/orion/image/harddisk.mk
index fb2f351..5e81344 100644
--- a/target/linux/orion/image/harddisk.mk
+++ b/target/linux/orion/image/harddisk.mk
@@ -11,7 +11,7 @@ define Image/BuildKernelMachId
 	$(STAGING_DIR_HOST)/bin/mkimage -A arm -O linux -T kernel \
 	-C none -a 0x00008000 -e 0x00008000 -n 'Linux-$(LINUX_VERSION)' \
 	-d $(KDIR)/$(1)-zImage $(KDIR)/$(1)-uImage
-	cp $(KDIR)/$(1)-uImage $(BIN_DIR)/openwrt-$(1)-uImage
+	cp $(KDIR)/$(1)-uImage $(BIN_DIR)/lede-$(1)-uImage
 endef
 
 define Image/BuildKernel
@@ -34,8 +34,8 @@ define Image/Build/Freecom
 	$(CP) $(KDIR)/dt2-uImage $(TARGET_DIR)/boot/uImage
 	$(INSTALL_DIR) $(TARGET_DIR)/var
  # create image
-	$(TAR) cfj $(BIN_DIR)/openwrt-$(2)-$(1).img --numeric-owner --owner=0 --group=0 -C $(TARGET_DIR)/ .
-	$(STAGING_DIR_HOST)/bin/encode_crc $(BIN_DIR)/openwrt-$(2)-$(1).img $(BIN_DIR)/openwrt-$(2)-$(1)-webupgrade.img $(3)
+	$(TAR) cfj $(BIN_DIR)/lede-$(2)-$(1).img --numeric-owner --owner=0 --group=0 -C $(TARGET_DIR)/ .
+	$(STAGING_DIR_HOST)/bin/encode_crc $(BIN_DIR)/lede-$(2)-$(1).img $(BIN_DIR)/lede-$(2)-$(1)-webupgrade.img $(3)
  # remove extra files
 	rm -rf $(TARGET_DIR)/{boot,var}
  # recover unwanted files
diff --git a/target/linux/ppc40x/image/Makefile b/target/linux/ppc40x/image/Makefile
index 4070774..1c32841 100644
--- a/target/linux/ppc40x/image/Makefile
+++ b/target/linux/ppc40x/image/Makefile
@@ -10,7 +10,7 @@ include $(INCLUDE_DIR)/image.mk
 JFFS2_BLOCKSIZE=128k 64k
 
 define Image/Prepare
-	$(LINUX_DIR)/scripts/dtc/dtc -O dtb -R 4 -S 0x20000 $(DTS_DIR)/kilauea.dts > $(KDIR)/openwrt-kilauea.dtb
+	$(LINUX_DIR)/scripts/dtc/dtc -O dtb -R 4 -S 0x20000 $(DTS_DIR)/kilauea.dts > $(KDIR)/lede-kilauea.dtb
 endef
 
 define Image/BuildKernel
@@ -29,7 +29,7 @@ endef
 define Image/Build/jffs2-128k
 	( \
 		dd if=$(KDIR)/uImage bs=1920k conv=sync; \
-		dd if=$(KDIR)/openwrt-kilauea.dtb bs=128k conv=sync; \
+		dd if=$(KDIR)/lede-kilauea.dtb bs=128k conv=sync; \
 		dd if=$(KDIR)/root.$(1) bs=128k conv=sync; \
 	) > $(BIN_DIR)/$(IMG_PREFIX)-kilauea-jffs2.img
 endef
@@ -49,7 +49,7 @@ define Image/Build/squashfs
 	$(call prepare_generic_squashfs,$(KDIR)/root.squashfs)
 	( \
 		dd if=$(KDIR)/uImage bs=1920k conv=sync; \
-		dd if=$(KDIR)/openwrt-kilauea.dtb bs=128k conv=sync; \
+		dd if=$(KDIR)/lede-kilauea.dtb bs=128k conv=sync; \
 		dd if=$(KDIR)/root.$(1) bs=128k conv=sync; \
 	) > $(BIN_DIR)/$(IMG_PREFIX)-kilauea-$(1).img
 	( \
@@ -64,8 +64,8 @@ endef
 
 ifneq ($(CONFIG_TARGET_ROOTFS_INITRAMFS),)
 define Image/Build/Initramfs
-	cp $(KDIR)/cuImage.magicbox-initramfs $(BIN_DIR)/openwrt-$(BOARD)-magicbox-initramfs.bin
-	cp $(KDIR)/cuImage.openrb-initramfs $(BIN_DIR)/openwrt-$(BOARD)-openrb-initramfs.bin
+	cp $(KDIR)/cuImage.magicbox-initramfs $(BIN_DIR)/lede-$(BOARD)-magicbox-initramfs.bin
+	cp $(KDIR)/cuImage.openrb-initramfs $(BIN_DIR)/lede-$(BOARD)-openrb-initramfs.bin
 endef
 endif
 
diff --git a/target/linux/ppc44x/image/Makefile b/target/linux/ppc44x/image/Makefile
index e2303f6..58c3a16 100644
--- a/target/linux/ppc44x/image/Makefile
+++ b/target/linux/ppc44x/image/Makefile
@@ -12,7 +12,7 @@ include $(INCLUDE_DIR)/image.mk
 
 
 define Image/Prepare
-	$(LINUX_DIR)/scripts/dtc/dtc -O dtb -R 4 -S 0x20000 $(DTS_DIR)/canyonlands.dts > $(KDIR)/openwrt-canyonlands.dtb
+	$(LINUX_DIR)/scripts/dtc/dtc -O dtb -R 4 -S 0x20000 $(DTS_DIR)/canyonlands.dts > $(KDIR)/lede-canyonlands.dtb
 endef
 
 define Image/BuildKernel
diff --git a/target/linux/ramips/patches-4.4/0002-MIPS-ralink-add-MT7621-defconfig.patch b/target/linux/ramips/patches-4.4/0002-MIPS-ralink-add-MT7621-defconfig.patch
index d788f2f..30a0578 100644
--- a/target/linux/ramips/patches-4.4/0002-MIPS-ralink-add-MT7621-defconfig.patch
+++ b/target/linux/ramips/patches-4.4/0002-MIPS-ralink-add-MT7621-defconfig.patch
@@ -18,7 +18,7 @@ Signed-off-by: John Crispin <blogic@openwrt.org>
 +CONFIG_RCU_FANOUT=32
 +CONFIG_UIDGID_STRICT_TYPE_CHECKS=y
 +CONFIG_BLK_DEV_INITRD=y
-+CONFIG_INITRAMFS_SOURCE="/openwrt/trunk/build_dir/target-mipsel_24kec+dsp_uClibc-0.9.33.2/root-ramips /openwrt/trunk/target/linux/generic/image/initramfs-base-files.txt"
++CONFIG_INITRAMFS_SOURCE="/lede/trunk/build_dir/target-mipsel_24kec+dsp_uClibc-0.9.33.2/root-ramips /lede/trunk/target/linux/generic/image/initramfs-base-files.txt"
 +CONFIG_INITRAMFS_ROOT_UID=1000
 +CONFIG_INITRAMFS_ROOT_GID=1000
 +# CONFIG_RD_GZIP is not set
diff --git a/target/linux/rb532/base-files/sbin/wget2nand b/target/linux/rb532/base-files/sbin/wget2nand
index 9a111fa..0d59381 100755
--- a/target/linux/rb532/base-files/sbin/wget2nand
+++ b/target/linux/rb532/base-files/sbin/wget2nand
@@ -44,8 +44,8 @@ mount -t yaffs2 "$main" /tmp/wget2nand/
 mount -t yaffs2 "$boot" /tmp/wget2nand-boot
 
 echo "Copying filesystem..."
-( wget -O - $url/openwrt-rb532-rootfs.tgz) | ( cd /tmp/wget2nand/; tar xvz )
-wget -O /tmp/wget2nand-boot/kernel $url/openwrt-rb532-vmlinux
+( wget -O - $url/lede-rb532-rootfs.tgz) | ( cd /tmp/wget2nand/; tar xvz )
+wget -O /tmp/wget2nand-boot/kernel $url/lede-rb532-vmlinux
 
 # No need to patch the kernel, this was done during the build process
 chmod +x /tmp/wget2nand-boot/kernel
diff --git a/target/linux/realview/README b/target/linux/realview/README
index db620f4..e44f20f 100644
--- a/target/linux/realview/README
+++ b/target/linux/realview/README
@@ -3,10 +3,10 @@ It can be used to prototype an OpenWrt firmware targetting ARM-based hardware.
 One could also use it to troubleshoot ARM applications without access to real
 hardware.
 
-To use the images built by OpenWrt with qemu, use the following commands:
+To use the images built by LEDE with qemu, use the following commands:
 
 qemu-system-arm -M realview-eb-mpcore \
--kernel bin/realview/openwrt-realview-vmlinux.elf \
+-kernel bin/realview/lede-realview-vmlinux.elf \
 -nographic -m 128
 
 and enjoy the system booting.
diff --git a/target/linux/sunxi/image/Makefile b/target/linux/sunxi/image/Makefile
index bda690e..abdd0fd 100644
--- a/target/linux/sunxi/image/Makefile
+++ b/target/linux/sunxi/image/Makefile
@@ -16,7 +16,7 @@ define Image/BuildKernel
 
 	mkimage -A arm -O linux -T kernel -C none \
 		-a 0x40008000 -e 0x40008000 \
-		-n 'ARM OpenWrt Linux-$(LINUX_VERSION)' \
+		-n 'ARM LEDE Linux-$(LINUX_VERSION)' \
 		-d $(KDIR)/zImage $(BIN_DIR)/$(IMG_PREFIX)-uImage
 
     ifneq ($(CONFIG_TARGET_ROOTFS_INITRAMFS),)
diff --git a/target/linux/uml/README b/target/linux/uml/README
index 85684ae..412222a 100644
--- a/target/linux/uml/README
+++ b/target/linux/uml/README
@@ -1,4 +1,4 @@
-Openwrt inside a user mode linux.  Why would we even want this many ask?
+LEDE inside a user mode linux.  Why would we even want this many ask?
 
 There are potentially a lot of reasons, one obvious one to me, it allows
 folks to 'kick the tires' without actually flashing up any hardware.  It's
@@ -17,7 +17,7 @@ build it all
 In your bin directory you will find a kernel and an ext4 root file system
 when it's finished.  Just run it like this:-
 
-bin/uml/openwrt-uml-vmlinux ubd0=bin/uml/openwrt-uml-ext4.img
+bin/uml/lede-uml-vmlinux ubd0=bin/uml/openwrt-uml-ext4.img
 
 The uml will start, and eventually the serial console of the uml will be at your
 console prompt.  If you would like it in xterms, substitute con=xterm and con0=xterm.
diff --git a/target/linux/xburst/image/Makefile b/target/linux/xburst/image/Makefile
index 0853607..537fad4 100644
--- a/target/linux/xburst/image/Makefile
+++ b/target/linux/xburst/image/Makefile
@@ -28,7 +28,7 @@ endef
 define MkImageGzip
 	gzip -9n -c $(1) > $(1).gz
 	mkimage -A mips -O linux -T kernel -a 0x80010000 -C gzip \
-		-e $(call kernel_entry,$(KDIR)/vmlinux.debug) -n 'MIPS OpenWrt Linux-$(LINUX_VERSION)' \
+		-e $(call kernel_entry,$(KDIR)/vmlinux.debug) -n 'MIPS LEDE Linux-$(LINUX_VERSION)' \
 		-d $(1).gz $(2)
 endef
 
diff --git a/target/linux/zynq/image/mkits.sh b/target/linux/zynq/image/mkits.sh
index 2b00d0f..7aaa12f 100755
--- a/target/linux/zynq/image/mkits.sh
+++ b/target/linux/zynq/image/mkits.sh
@@ -63,7 +63,7 @@ ARCH_UPPER=`echo $ARCH | tr '[:lower:]' '[:upper:]'`
 if [ -n "${DTB}" ]; then
 	FDT="
 		fdt@1 {
-			description = \"${ARCH_UPPER} OpenWrt ${DEVICE} device tree blob\";
+			description = \"${ARCH_UPPER} LEDE ${DEVICE} device tree blob\";
 			data = /incbin/(\"${DTB}\");
 			type = \"flat_dt\";
 			arch = \"${ARCH}\";
@@ -84,7 +84,7 @@ if [ -n "${RAMDISK}" ]; then
 	RD_COMPRESS=${RD_COMPRESS:-none}
 	RD="
 		ramdisk@1 {
-			description = \"${ARCH_UPPER} OpenWrt ${DEVICE} ramdisk\";
+			description = \"${ARCH_UPPER} LEDE ${DEVICE} ramdisk\";
 			data = /incbin/(\"${RAMDISK}\");
 			type = \"ramdisk\";
 			arch = \"${ARCH}\";
@@ -110,12 +110,12 @@ fi
 DATA="/dts-v1/;
 
 / {
-	description = \"${ARCH_UPPER} OpenWrt FIT (Flattened Image Tree)\";
+	description = \"${ARCH_UPPER} LEDE FIT (Flattened Image Tree)\";
 	#address-cells = <1>;
 
 	images {
 		kernel@1 {
-			description = \"${ARCH_UPPER} OpenWrt Linux-${VERSION}\";
+			description = \"${ARCH_UPPER} LEDE Linux-${VERSION}\";
 			data = /incbin/(\"${KERNEL}\");
 			type = \"kernel\";
 			arch = \"${ARCH}\";
@@ -139,7 +139,7 @@ ${FDT}
 	configurations {
 		default = \"config@1\";
 		config@1 {
-			description = \"OpenWrt\";
+			description = \"LEDE\";
 			kernel = \"kernel@1\";
 ${CONF}
 		};
diff --git a/tools/libtool/files/libtool-v1.5.patch b/tools/libtool/files/libtool-v1.5.patch
index 485dfc7..550295f 100644
--- a/tools/libtool/files/libtool-v1.5.patch
+++ b/tools/libtool/files/libtool-v1.5.patch
@@ -5,7 +5,7 @@
  # The name of this program:
  progname=`echo "$progpath" | $SED $basename`
 -modename="$progname"
-+modename="OpenWrt-$progname-patched-1.5"
++modename="LEDE-$progname-patched-1.5"
  
  # Global variables:
  EXIT_SUCCESS=0
diff --git a/tools/libtool/files/libtool-v2.2.patch b/tools/libtool/files/libtool-v2.2.patch
index 03994ba..e2bdb0a 100644
--- a/tools/libtool/files/libtool-v2.2.patch
+++ b/tools/libtool/files/libtool-v2.2.patch
@@ -5,7 +5,7 @@
  func_echo ()
  {
 -    $ECHO "$progname${mode+: }$mode: $*"
-+    $ECHO "OpenWrt-$progname-patched-2.2${mode+: }$mode: $*"
++    $ECHO "LEDE-$progname-patched-2.2${mode+: }$mode: $*"
  }
  
  # func_verbose arg...
@@ -14,7 +14,7 @@
  func_error ()
  {
 -    $ECHO "$progname${mode+: }$mode: "${1+"$@"} 1>&2
-+    $ECHO "OpenWrt-$progname-patched-2.2${mode+: }$mode: "${1+"$@"} 1>&2
++    $ECHO "LEDE-$progname-patched-2.2${mode+: }$mode: "${1+"$@"} 1>&2
  }
  
  # func_warning arg...
@@ -22,7 +22,7 @@
  func_warning ()
  {
 -    $opt_warning && $ECHO "$progname${mode+: }$mode: warning: "${1+"$@"} 1>&2
-+    $opt_warning && $ECHO "OpenWrt-$progname-patched-2.2${mode+: }$mode: warning: "${1+"$@"} 1>&2
++    $opt_warning && $ECHO "LEDE-$progname-patched-2.2${mode+: }$mode: warning: "${1+"$@"} 1>&2
  
      # bash bug again:
      :
diff --git a/tools/libtool/files/libtool-v2.4.patch b/tools/libtool/files/libtool-v2.4.patch
index afc754a..6d14495 100644
--- a/tools/libtool/files/libtool-v2.4.patch
+++ b/tools/libtool/files/libtool-v2.4.patch
@@ -5,7 +5,7 @@
  func_echo ()
  {
 -    $ECHO "$progname: ${opt_mode+$opt_mode: }$*"
-+    $ECHO "OpenWrt-$progname-patched-2.4: ${opt_mode+$opt_mode: }$*"
++    $ECHO "LEDE-$progname-patched-2.4: ${opt_mode+$opt_mode: }$*"
  }
  
  # func_verbose arg...
@@ -14,7 +14,7 @@
  func_error ()
  {
 -    $ECHO "$progname: ${opt_mode+$opt_mode: }"${1+"$@"} 1>&2
-+    $ECHO "OpenWrt-$progname-patched-2.4: ${opt_mode+$opt_mode: }"${1+"$@"} 1>&2
++    $ECHO "LEDE-$progname-patched-2.4: ${opt_mode+$opt_mode: }"${1+"$@"} 1>&2
  }
  
  # func_warning arg...
@@ -22,7 +22,7 @@
  func_warning ()
  {
 -    $opt_warning && $ECHO "$progname: ${opt_mode+$opt_mode: }warning: "${1+"$@"} 1>&2
-+    $opt_warning && $ECHO "OpenWrt-$progname-patched-2.4: ${opt_mode+$opt_mode: }warning: "${1+"$@"} 1>&2
++    $opt_warning && $ECHO "LEDE-$progname-patched-2.4: ${opt_mode+$opt_mode: }warning: "${1+"$@"} 1>&2
  
      # bash bug again:
      :
diff --git a/tools/libtool/patches/200-lede-branding.patch b/tools/libtool/patches/200-lede-branding.patch
new file mode 100644
index 0000000..c0d79ac
--- /dev/null
+++ b/tools/libtool/patches/200-lede-branding.patch
@@ -0,0 +1,112 @@
+--- a/libltdl/config/general.m4sh
++++ b/libltdl/config/general.m4sh
+@@ -359,7 +359,7 @@ opt_warning=:
+ # name if it has been set yet.
+ func_echo ()
+ {
+-    $ECHO "$progname: ${opt_mode+$opt_mode: }$*"
++    $ECHO "LEDE-$progname: ${opt_mode+$opt_mode: }$*"
+ }
+ 
+ # func_verbose arg...
+@@ -385,14 +385,14 @@ func_echo_all ()
+ # Echo program name prefixed message to standard error.
+ func_error ()
+ {
+-    $ECHO "$progname: ${opt_mode+$opt_mode: }"${1+"$@"} 1>&2
++    $ECHO "LEDE-$progname: ${opt_mode+$opt_mode: }"${1+"$@"} 1>&2
+ }
+ 
+ # func_warning arg...
+ # Echo program name prefixed warning message to standard error.
+ func_warning ()
+ {
+-    $opt_warning && $ECHO "$progname: ${opt_mode+$opt_mode: }warning: "${1+"$@"} 1>&2
++    $opt_warning && $ECHO "LEDE-$progname: ${opt_mode+$opt_mode: }warning: "${1+"$@"} 1>&2
+ 
+     # bash bug again:
+     :
+--- a/libltdl/config/ltmain.sh
++++ b/libltdl/config/ltmain.sh
+@@ -443,7 +443,7 @@ opt_warning=:
+ # name if it has been set yet.
+ func_echo ()
+ {
+-    $ECHO "$progname: ${opt_mode+$opt_mode: }$*"
++    $ECHO "LEDE-$progname: ${opt_mode+$opt_mode: }$*"
+ }
+ 
+ # func_verbose arg...
+@@ -469,14 +469,14 @@ func_echo_all ()
+ # Echo program name prefixed message to standard error.
+ func_error ()
+ {
+-    $ECHO "$progname: ${opt_mode+$opt_mode: }"${1+"$@"} 1>&2
++    $ECHO "LEDE-$progname: ${opt_mode+$opt_mode: }"${1+"$@"} 1>&2
+ }
+ 
+ # func_warning arg...
+ # Echo program name prefixed warning message to standard error.
+ func_warning ()
+ {
+-    $opt_warning && $ECHO "$progname: ${opt_mode+$opt_mode: }warning: "${1+"$@"} 1>&2
++    $opt_warning && $ECHO "LEDE-$progname: ${opt_mode+$opt_mode: }warning: "${1+"$@"} 1>&2
+ 
+     # bash bug again:
+     :
+--- a/libtoolize.in
++++ b/libtoolize.in
+@@ -640,7 +640,7 @@ opt_warning=:
+ # name if it has been set yet.
+ func_echo ()
+ {
+-    $ECHO "$progname: ${opt_mode+$opt_mode: }$*"
++    $ECHO "LEDE-$progname: ${opt_mode+$opt_mode: }$*"
+ }
+ 
+ # func_verbose arg...
+@@ -666,14 +666,14 @@ func_echo_all ()
+ # Echo program name prefixed message to standard error.
+ func_error ()
+ {
+-    $ECHO "$progname: ${opt_mode+$opt_mode: }"${1+"$@"} 1>&2
++    $ECHO "LEDE-$progname: ${opt_mode+$opt_mode: }"${1+"$@"} 1>&2
+ }
+ 
+ # func_warning arg...
+ # Echo program name prefixed warning message to standard error.
+ func_warning ()
+ {
+-    $opt_warning && $ECHO "$progname: ${opt_mode+$opt_mode: }warning: "${1+"$@"} 1>&2
++    $opt_warning && $ECHO "LEDE-$progname: ${opt_mode+$opt_mode: }warning: "${1+"$@"} 1>&2
+ 
+     # bash bug again:
+     :
+--- a/tests/defs.in
++++ b/tests/defs.in
+@@ -588,7 +588,7 @@ opt_warning=:
+ # name if it has been set yet.
+ func_echo ()
+ {
+-    $ECHO "$progname: ${opt_mode+$opt_mode: }$*"
++    $ECHO "LEDE-$progname: ${opt_mode+$opt_mode: }$*"
+ }
+ 
+ # func_verbose arg...
+@@ -614,14 +614,14 @@ func_echo_all ()
+ # Echo program name prefixed message to standard error.
+ func_error ()
+ {
+-    $ECHO "$progname: ${opt_mode+$opt_mode: }"${1+"$@"} 1>&2
++    $ECHO "LEDE-$progname: ${opt_mode+$opt_mode: }"${1+"$@"} 1>&2
+ }
+ 
+ # func_warning arg...
+ # Echo program name prefixed warning message to standard error.
+ func_warning ()
+ {
+-    $opt_warning && $ECHO "$progname: ${opt_mode+$opt_mode: }warning: "${1+"$@"} 1>&2
++    $opt_warning && $ECHO "LEDE-$progname: ${opt_mode+$opt_mode: }warning: "${1+"$@"} 1>&2
+ 
+     # bash bug again:
+     :
diff --git a/tools/libtool/patches/200-openwrt-branding.patch b/tools/libtool/patches/200-openwrt-branding.patch
deleted file mode 100644
index dd3e3d6..0000000
--- a/tools/libtool/patches/200-openwrt-branding.patch
+++ /dev/null
@@ -1,112 +0,0 @@
---- a/libltdl/config/general.m4sh
-+++ b/libltdl/config/general.m4sh
-@@ -359,7 +359,7 @@ opt_warning=:
- # name if it has been set yet.
- func_echo ()
- {
--    $ECHO "$progname: ${opt_mode+$opt_mode: }$*"
-+    $ECHO "OpenWrt-$progname: ${opt_mode+$opt_mode: }$*"
- }
- 
- # func_verbose arg...
-@@ -385,14 +385,14 @@ func_echo_all ()
- # Echo program name prefixed message to standard error.
- func_error ()
- {
--    $ECHO "$progname: ${opt_mode+$opt_mode: }"${1+"$@"} 1>&2
-+    $ECHO "OpenWrt-$progname: ${opt_mode+$opt_mode: }"${1+"$@"} 1>&2
- }
- 
- # func_warning arg...
- # Echo program name prefixed warning message to standard error.
- func_warning ()
- {
--    $opt_warning && $ECHO "$progname: ${opt_mode+$opt_mode: }warning: "${1+"$@"} 1>&2
-+    $opt_warning && $ECHO "OpenWrt-$progname: ${opt_mode+$opt_mode: }warning: "${1+"$@"} 1>&2
- 
-     # bash bug again:
-     :
---- a/libltdl/config/ltmain.sh
-+++ b/libltdl/config/ltmain.sh
-@@ -443,7 +443,7 @@ opt_warning=:
- # name if it has been set yet.
- func_echo ()
- {
--    $ECHO "$progname: ${opt_mode+$opt_mode: }$*"
-+    $ECHO "OpenWrt-$progname: ${opt_mode+$opt_mode: }$*"
- }
- 
- # func_verbose arg...
-@@ -469,14 +469,14 @@ func_echo_all ()
- # Echo program name prefixed message to standard error.
- func_error ()
- {
--    $ECHO "$progname: ${opt_mode+$opt_mode: }"${1+"$@"} 1>&2
-+    $ECHO "OpenWrt-$progname: ${opt_mode+$opt_mode: }"${1+"$@"} 1>&2
- }
- 
- # func_warning arg...
- # Echo program name prefixed warning message to standard error.
- func_warning ()
- {
--    $opt_warning && $ECHO "$progname: ${opt_mode+$opt_mode: }warning: "${1+"$@"} 1>&2
-+    $opt_warning && $ECHO "OpenWrt-$progname: ${opt_mode+$opt_mode: }warning: "${1+"$@"} 1>&2
- 
-     # bash bug again:
-     :
---- a/libtoolize.in
-+++ b/libtoolize.in
-@@ -640,7 +640,7 @@ opt_warning=:
- # name if it has been set yet.
- func_echo ()
- {
--    $ECHO "$progname: ${opt_mode+$opt_mode: }$*"
-+    $ECHO "OpenWrt-$progname: ${opt_mode+$opt_mode: }$*"
- }
- 
- # func_verbose arg...
-@@ -666,14 +666,14 @@ func_echo_all ()
- # Echo program name prefixed message to standard error.
- func_error ()
- {
--    $ECHO "$progname: ${opt_mode+$opt_mode: }"${1+"$@"} 1>&2
-+    $ECHO "OpenWrt-$progname: ${opt_mode+$opt_mode: }"${1+"$@"} 1>&2
- }
- 
- # func_warning arg...
- # Echo program name prefixed warning message to standard error.
- func_warning ()
- {
--    $opt_warning && $ECHO "$progname: ${opt_mode+$opt_mode: }warning: "${1+"$@"} 1>&2
-+    $opt_warning && $ECHO "OpenWrt-$progname: ${opt_mode+$opt_mode: }warning: "${1+"$@"} 1>&2
- 
-     # bash bug again:
-     :
---- a/tests/defs.in
-+++ b/tests/defs.in
-@@ -588,7 +588,7 @@ opt_warning=:
- # name if it has been set yet.
- func_echo ()
- {
--    $ECHO "$progname: ${opt_mode+$opt_mode: }$*"
-+    $ECHO "OpenWrt-$progname: ${opt_mode+$opt_mode: }$*"
- }
- 
- # func_verbose arg...
-@@ -614,14 +614,14 @@ func_echo_all ()
- # Echo program name prefixed message to standard error.
- func_error ()
- {
--    $ECHO "$progname: ${opt_mode+$opt_mode: }"${1+"$@"} 1>&2
-+    $ECHO "OpenWrt-$progname: ${opt_mode+$opt_mode: }"${1+"$@"} 1>&2
- }
- 
- # func_warning arg...
- # Echo program name prefixed warning message to standard error.
- func_warning ()
- {
--    $opt_warning && $ECHO "$progname: ${opt_mode+$opt_mode: }warning: "${1+"$@"} 1>&2
-+    $opt_warning && $ECHO "OpenWrt-$progname: ${opt_mode+$opt_mode: }warning: "${1+"$@"} 1>&2
- 
-     # bash bug again:
-     :
diff --git a/tools/wrt350nv2-builder/src/wrt350nv2-builder.c b/tools/wrt350nv2-builder/src/wrt350nv2-builder.c
index 3ebb40e..9c45fc6 100644
--- a/tools/wrt350nv2-builder/src/wrt350nv2-builder.c
+++ b/tools/wrt350nv2-builder/src/wrt350nv2-builder.c
@@ -34,7 +34,7 @@
 		#version	0x2020
 
 	Additionally since v2.4 an already complete image can be used:
-		:image		0	/path/to/openwrt-wrt350nv2-[squashfs|jffs2-64k].img
+		:image		0	/path/to/lede-wrt350nv2-[squashfs|jffs2-64k].img
 
 	args:
 		1	wrt350nv2.par		parameter file describing the image layout

diff --git a/scripts/flashing/adam2flash-502T.pl b/scripts/flashing/adam2flash-502T.pl
index 0c4c9d7..99d5e07 100755
--- a/scripts/flashing/adam2flash-502T.pl
+++ b/scripts/flashing/adam2flash-502T.pl
@@ -44,7 +44,7 @@
 # that the image appears to extend beyond the end of mtd1, it will refuse to load it. On
 # the DSL-502T, this manifests as the USB light blinking rapidly on boot.
 #
 # The OpenWRT kernel does not follow quite the same layout:
 #  (a) it does not have a 0x90-byte firmware signature prefix
 #  (b) it is larger than the default mtd1 size
 #
@@ -60,8 +60,8 @@
 #
 # *** NOTE NOTE NOTE NOTE ***
 #
 # /dev/mtd0 .. /dev/mtd4 when using OpenWRT do **NOT** correspond to the ADAM2 mtd0-4 settings!
 # Instead, OpenWRT scans the MTD itself and determines its own boundaries which are arranged
 # quite differently to ADAM2. It will look something like this, see dmsg on boot:
 #
 # (/dev/mtd0) 0x00000000-0x00010000 : "loader"        # Bootloader, read-only
@@ -86,7 +86,7 @@ sub usage() {
 	print STDERR "<ip> may be any spare address on the local subnet.\n\n";
 	print STDERR "If a firmware file is specified, MTD settings are verified and\n";
 	print STDERR "then the firmware is written to the router's flash.\n";
-	print STDERR "The firmware type (D-Link or OpenWRT) is automatically detected.\n\n";
+	print STDERR "The firmware type (D-Link or LEDE) is automatically detected.\n\n";
 	print STDERR "  -setmtd1  update mtd1 if it is not the appropriate value for this firmware\n";
 	print STDERR "  -noflash  does normal checks, updates mtd1 if requested, but does not actually write firmware\n\n";
 	exit 0;
@@ -210,7 +210,7 @@ if (!$file) {
 open FILE, "<$file" or die "can't open firmware file\n";
 
 # D-Link firmware starts with "MTD4" little-endian, then has an image header at 0x90
 # OpenWRT firmware just starts with an image header at 0x00
 
 my $signature;
 my $sbytes = read FILE, $signature, 4;
@@ -232,10 +232,10 @@ if ($signature eq "4DTM") {
     $expectedmtd1 = "0x90010090,0x90091000";
   }
 } elsif ($signature eq "\x42\xfa\xed\xfe") {
-  $fwtype = "OpenWRT (little-endian)";
+  $fwtype = "LEDE (little-endian)";
   $expectedmtd1 = "0x90010000,0x903f0000";
 } elsif ($signature eq "\xde\xad\xbe\x42") {
-  $fwtype = "OpenWRT (big-endian)";
+  $fwtype = "LEDE (big-endian)";
   $expectedmtd1 = "0x90010000,0x903f0000";
 }
 
@@ -44,7 +44,7 @@
 # the DSL-502T, this manifests as the USB light blinking rapidly on boot.
 #
-# The OpenWRT kernel does not follow quite the same layout:
+# The LEDE kernel does not follow quite the same layout:
 #  (a) it does not have a 0x90-byte firmware signature prefix
 #  (b) it is larger than the default mtd1 size
@@ -60,8 +60,8 @@
 # *** NOTE NOTE NOTE NOTE ***
 #
-# /dev/mtd0 .. /dev/mtd4 when using OpenWRT do **NOT** correspond to the ADAM2 mtd0-4 settings!
-# Instead, OpenWRT scans the MTD itself and determines its own boundaries which are arranged
+# /dev/mtd0 .. /dev/mtd4 when using LEDE do **NOT** correspond to the ADAM2 mtd0-4 settings!
+# Instead, LEDE scans the MTD itself and determines its own boundaries which are arranged
 # quite differently to ADAM2. It will look something like this, see dmsg on boot:
 #
@@ -210,7 +210,7 @@ if (!$file) {
 
 # D-Link firmware starts with "MTD4" little-endian, then has an image header at 0x90
-# OpenWRT firmware just starts with an image header at 0x00
+# LEDE firmware just starts with an image header at 0x00
 
 my $signature;
diff --git a/target/linux/ar71xx/image/lzma-loader/src/loader.c b/target/linux/ar71xx/image/lzma-loader/src/loader.c
index cc73eb1..73dc4bf 100644
--- a/target/linux/ar71xx/image/lzma-loader/src/loader.c
+++ b/target/linux/ar71xx/image/lzma-loader/src/loader.c
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2011 Gabor Juhos <juhosg@openwrt.org>
  *
  * Some parts of this code was based on the OpenWrt specific lzma-loader
  * for the BCM47xx and ADM5120 based boards:
  *	Copyright (C) 2004 Manuel Novoa III (mjn3@codepoet.org)
  *	Copyright (C) 2005 Mineharu Takahara <mtakahar@yahoo.com>
@@ -179,7 +179,7 @@ static void lzma_init_data(void)
 
 	flash_base = (unsigned char *) KSEG1ADDR(AR71XX_FLASH_START);
 
-	printf("Looking for OpenWrt image... ");
+	printf("Looking for LEDE image... ");
 
 	for (flash_ofs = CONFIG_FLASH_OFFS;
 	     flash_ofs <= (CONFIG_FLASH_OFFS + CONFIG_FLASH_MAX);
@@ -220,7 +220,7 @@ void loader_main(unsigned long reg_a0, unsigned long reg_a1,
 
 	board_init();
 
-	printf("\n\nOpenWrt kernel loader for AR7XXX/AR9XXX\n");
+	printf("\n\nLEDE kernel loader for AR7XXX/AR9XXX\n");
 	printf("Copyright (C) 2011 Gabor Juhos <juhosg@openwrt.org>\n");
 
 	lzma_init_data();
@@ -3,7 +3,7 @@
  * Copyright (C) 2011 Gabor Juhos <juhosg@openwrt.org>
  *
- * Some parts of this code was based on the OpenWrt specific lzma-loader
+ * Some parts of this code was based on the LEDE specific lzma-loader
  * for the BCM47xx and ADM5120 based boards:
  *	Copyright (C) 2004 Manuel Novoa III (mjn3@codepoet.org)
diff --git a/target/linux/brcm63xx/image/lzma-loader/src/loader.c b/target/linux/brcm63xx/image/lzma-loader/src/loader.c
index 0848ce6..cd5ab87 100644
--- a/target/linux/brcm63xx/image/lzma-loader/src/loader.c
+++ b/target/linux/brcm63xx/image/lzma-loader/src/loader.c
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2011 Gabor Juhos <juhosg@openwrt.org>
  *
  * Some parts of this code was based on the OpenWrt specific lzma-loader
  * for the BCM47xx and ADM5120 based boards:
  *	Copyright (C) 2004 Manuel Novoa III (mjn3@codepoet.org)
  *	Copyright (C) 2005 Mineharu Takahara <mtakahar@yahoo.com>
@@ -137,7 +137,7 @@ void loader_main(unsigned long reg_a0, unsigned long reg_a1,
 
 	board_init();
 
-	printf("\n\nOpenWrt kernel loader for BCM63XX\n");
+	printf("\n\nLEDE kernel loader for BCM63XX\n");
 	printf("Copyright (C) 2011 Gabor Juhos <juhosg@openwrt.org>\n");
 	printf("Copyright (C) 2014 Jonas Gorski <jogo@openwrt.org>\n");
 
@@ -3,7 +3,7 @@
  * Copyright (C) 2011 Gabor Juhos <juhosg@openwrt.org>
  *
- * Some parts of this code was based on the OpenWrt specific lzma-loader
+ * Some parts of this code was based on the LEDE specific lzma-loader
  * for the BCM47xx and ADM5120 based boards:
  *	Copyright (C) 2004 Manuel Novoa III (mjn3@codepoet.org)
diff --git a/target/linux/lantiq/image/lzma-loader/src/loader.c b/target/linux/lantiq/image/lzma-loader/src/loader.c
index 1d42bfa..b04126a 100644
--- a/target/linux/lantiq/image/lzma-loader/src/loader.c
+++ b/target/linux/lantiq/image/lzma-loader/src/loader.c
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2011 Gabor Juhos <juhosg@openwrt.org>
  *
  * Some parts of this code was based on the OpenWrt specific lzma-loader
  * for the BCM47xx and ADM5120 based boards:
  *	Copyright (C) 2004 Manuel Novoa III (mjn3@codepoet.org)
  *	Copyright (C) 2005 Mineharu Takahara <mtakahar@yahoo.com>
@@ -178,7 +178,7 @@ static void lzma_init_data(void)
 
 	flash_base = (unsigned char *) KSEG1ADDR(AR71XX_FLASH_START);
 
-	printf("Looking for OpenWrt image... ");
+	printf("Looking for LEDE image... ");
 
 	for (flash_ofs = CONFIG_FLASH_OFFS;
 	     flash_ofs <= (CONFIG_FLASH_OFFS + CONFIG_FLASH_MAX);
@@ -219,7 +219,7 @@ void loader_main(unsigned long reg_a0, unsigned long reg_a1,
 
 	board_init();
 
-	printf("\n\nOpenWrt kernel loader for MIPS based SoC\n");
+	printf("\n\nLEDE kernel loader for MIPS based SoC\n");
 	printf("Copyright (C) 2011 Gabor Juhos <juhosg@openwrt.org>\n");
 
 	lzma_init_data();
@@ -3,7 +3,7 @@
  * Copyright (C) 2011 Gabor Juhos <juhosg@openwrt.org>
  *
- * Some parts of this code was based on the OpenWrt specific lzma-loader
+ * Some parts of this code was based on the LEDE specific lzma-loader
  * for the BCM47xx and ADM5120 based boards:
  *	Copyright (C) 2004 Manuel Novoa III (mjn3@codepoet.org)